#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IotDevicePrincipal import IotDevicePrincipal


class AlipayCommerceIotMdeviceprodDeviceBindModel(object):

    def __init__(self):
        self._biz_tid = None
        self._device_sn = None
        self._ext_info = None
        self._identify_type = None
        self._principal = None
        self._supplier_id = None

    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value
    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def identify_type(self):
        return self._identify_type

    @identify_type.setter
    def identify_type(self, value):
        self._identify_type = value
    @property
    def principal(self):
        return self._principal

    @principal.setter
    def principal(self, value):
        if isinstance(value, list):
            self._principal = list()
            for i in value:
                if isinstance(i, IotDevicePrincipal):
                    self._principal.append(i)
                else:
                    self._principal.append(IotDevicePrincipal.from_alipay_dict(i))
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.identify_type:
            if hasattr(self.identify_type, 'to_alipay_dict'):
                params['identify_type'] = self.identify_type.to_alipay_dict()
            else:
                params['identify_type'] = self.identify_type
        if self.principal:
            if isinstance(self.principal, list):
                for i in range(0, len(self.principal)):
                    element = self.principal[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.principal[i] = element.to_alipay_dict()
            if hasattr(self.principal, 'to_alipay_dict'):
                params['principal'] = self.principal.to_alipay_dict()
            else:
                params['principal'] = self.principal
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotMdeviceprodDeviceBindModel()
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'identify_type' in d:
            o.identify_type = d['identify_type']
        if 'principal' in d:
            o.principal = d['principal']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityProdFingerprintVerifyModel(object):

    def __init__(self):
        self._extend_param = None
        self._ifaa_version = None
        self._ifaf_message = None
        self._out_biz_no = None
        self._sec_data = None

    @property
    def extend_param(self):
        return self._extend_param

    @extend_param.setter
    def extend_param(self, value):
        self._extend_param = value
    @property
    def ifaa_version(self):
        return self._ifaa_version

    @ifaa_version.setter
    def ifaa_version(self, value):
        self._ifaa_version = value
    @property
    def ifaf_message(self):
        return self._ifaf_message

    @ifaf_message.setter
    def ifaf_message(self, value):
        self._ifaf_message = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def sec_data(self):
        return self._sec_data

    @sec_data.setter
    def sec_data(self, value):
        self._sec_data = value


    def to_alipay_dict(self):
        params = dict()
        if self.extend_param:
            if hasattr(self.extend_param, 'to_alipay_dict'):
                params['extend_param'] = self.extend_param.to_alipay_dict()
            else:
                params['extend_param'] = self.extend_param
        if self.ifaa_version:
            if hasattr(self.ifaa_version, 'to_alipay_dict'):
                params['ifaa_version'] = self.ifaa_version.to_alipay_dict()
            else:
                params['ifaa_version'] = self.ifaa_version
        if self.ifaf_message:
            if hasattr(self.ifaf_message, 'to_alipay_dict'):
                params['ifaf_message'] = self.ifaf_message.to_alipay_dict()
            else:
                params['ifaf_message'] = self.ifaf_message
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.sec_data:
            if hasattr(self.sec_data, 'to_alipay_dict'):
                params['sec_data'] = self.sec_data.to_alipay_dict()
            else:
                params['sec_data'] = self.sec_data
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityProdFingerprintVerifyModel()
        if 'extend_param' in d:
            o.extend_param = d['extend_param']
        if 'ifaa_version' in d:
            o.ifaa_version = d['ifaa_version']
        if 'ifaf_message' in d:
            o.ifaf_message = d['ifaf_message']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'sec_data' in d:
            o.sec_data = d['sec_data']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SkuPropsDetail(object):

    def __init__(self):
        self._image = None
        self._name = None
        self._vid = None

    @property
    def image(self):
        return self._image

    @image.setter
    def image(self, value):
        self._image = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def vid(self):
        return self._vid

    @vid.setter
    def vid(self, value):
        self._vid = value


    def to_alipay_dict(self):
        params = dict()
        if self.image:
            if hasattr(self.image, 'to_alipay_dict'):
                params['image'] = self.image.to_alipay_dict()
            else:
                params['image'] = self.image
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.vid:
            if hasattr(self.vid, 'to_alipay_dict'):
                params['vid'] = self.vid.to_alipay_dict()
            else:
                params['vid'] = self.vid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SkuPropsDetail()
        if 'image' in d:
            o.image = d['image']
        if 'name' in d:
            o.name = d['name']
        if 'vid' in d:
            o.vid = d['vid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ProdRelationVO(object):

    def __init__(self):
        self._num = None
        self._num_type = None
        self._prod_code = None
        self._prod_rel_code = None
        self._prod_rel_name = None
        self._prod_rel_type = None
        self._prod_rel_version = None
        self._prod_version = None
        self._sub_prod_rel_type = None

    @property
    def num(self):
        return self._num

    @num.setter
    def num(self, value):
        self._num = value
    @property
    def num_type(self):
        return self._num_type

    @num_type.setter
    def num_type(self, value):
        self._num_type = value
    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value
    @property
    def prod_rel_code(self):
        return self._prod_rel_code

    @prod_rel_code.setter
    def prod_rel_code(self, value):
        self._prod_rel_code = value
    @property
    def prod_rel_name(self):
        return self._prod_rel_name

    @prod_rel_name.setter
    def prod_rel_name(self, value):
        self._prod_rel_name = value
    @property
    def prod_rel_type(self):
        return self._prod_rel_type

    @prod_rel_type.setter
    def prod_rel_type(self, value):
        self._prod_rel_type = value
    @property
    def prod_rel_version(self):
        return self._prod_rel_version

    @prod_rel_version.setter
    def prod_rel_version(self, value):
        self._prod_rel_version = value
    @property
    def prod_version(self):
        return self._prod_version

    @prod_version.setter
    def prod_version(self, value):
        self._prod_version = value
    @property
    def sub_prod_rel_type(self):
        return self._sub_prod_rel_type

    @sub_prod_rel_type.setter
    def sub_prod_rel_type(self, value):
        self._sub_prod_rel_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.num:
            if hasattr(self.num, 'to_alipay_dict'):
                params['num'] = self.num.to_alipay_dict()
            else:
                params['num'] = self.num
        if self.num_type:
            if hasattr(self.num_type, 'to_alipay_dict'):
                params['num_type'] = self.num_type.to_alipay_dict()
            else:
                params['num_type'] = self.num_type
        if self.prod_code:
            if hasattr(self.prod_code, 'to_alipay_dict'):
                params['prod_code'] = self.prod_code.to_alipay_dict()
            else:
                params['prod_code'] = self.prod_code
        if self.prod_rel_code:
            if hasattr(self.prod_rel_code, 'to_alipay_dict'):
                params['prod_rel_code'] = self.prod_rel_code.to_alipay_dict()
            else:
                params['prod_rel_code'] = self.prod_rel_code
        if self.prod_rel_name:
            if hasattr(self.prod_rel_name, 'to_alipay_dict'):
                params['prod_rel_name'] = self.prod_rel_name.to_alipay_dict()
            else:
                params['prod_rel_name'] = self.prod_rel_name
        if self.prod_rel_type:
            if hasattr(self.prod_rel_type, 'to_alipay_dict'):
                params['prod_rel_type'] = self.prod_rel_type.to_alipay_dict()
            else:
                params['prod_rel_type'] = self.prod_rel_type
        if self.prod_rel_version:
            if hasattr(self.prod_rel_version, 'to_alipay_dict'):
                params['prod_rel_version'] = self.prod_rel_version.to_alipay_dict()
            else:
                params['prod_rel_version'] = self.prod_rel_version
        if self.prod_version:
            if hasattr(self.prod_version, 'to_alipay_dict'):
                params['prod_version'] = self.prod_version.to_alipay_dict()
            else:
                params['prod_version'] = self.prod_version
        if self.sub_prod_rel_type:
            if hasattr(self.sub_prod_rel_type, 'to_alipay_dict'):
                params['sub_prod_rel_type'] = self.sub_prod_rel_type.to_alipay_dict()
            else:
                params['sub_prod_rel_type'] = self.sub_prod_rel_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ProdRelationVO()
        if 'num' in d:
            o.num = d['num']
        if 'num_type' in d:
            o.num_type = d['num_type']
        if 'prod_code' in d:
            o.prod_code = d['prod_code']
        if 'prod_rel_code' in d:
            o.prod_rel_code = d['prod_rel_code']
        if 'prod_rel_name' in d:
            o.prod_rel_name = d['prod_rel_name']
        if 'prod_rel_type' in d:
            o.prod_rel_type = d['prod_rel_type']
        if 'prod_rel_version' in d:
            o.prod_rel_version = d['prod_rel_version']
        if 'prod_version' in d:
            o.prod_version = d['prod_version']
        if 'sub_prod_rel_type' in d:
            o.sub_prod_rel_type = d['sub_prod_rel_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingToolXuanyitestQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingToolXuanyitestQueryResponse, self).__init__()
        self._test_100 = None
        self._test_101 = None

    @property
    def test_100(self):
        return self._test_100

    @test_100.setter
    def test_100(self, value):
        self._test_100 = value
    @property
    def test_101(self):
        return self._test_101

    @test_101.setter
    def test_101(self, value):
        self._test_101 = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingToolXuanyitestQueryResponse, self).parse_response_content(response_content)
        if 'test_100' in response:
            self.test_100 = response['test_100']
        if 'test_101' in response:
            self.test_101 = response['test_101']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenContentIotCouponQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenContentIotCouponQueryResponse, self).__init__()
        self._btn_act = None
        self._camp_id = None
        self._component_template = None
        self._content = None
        self._item_type = None
        self._nonempty_coupon_list = None
        self._prize_type = None
        self._shop_info = None
        self._url = None
        self._voice_broadcast = None

    @property
    def btn_act(self):
        return self._btn_act

    @btn_act.setter
    def btn_act(self, value):
        self._btn_act = value
    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value
    @property
    def component_template(self):
        return self._component_template

    @component_template.setter
    def component_template(self, value):
        self._component_template = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def item_type(self):
        return self._item_type

    @item_type.setter
    def item_type(self, value):
        self._item_type = value
    @property
    def nonempty_coupon_list(self):
        return self._nonempty_coupon_list

    @nonempty_coupon_list.setter
    def nonempty_coupon_list(self, value):
        self._nonempty_coupon_list = value
    @property
    def prize_type(self):
        return self._prize_type

    @prize_type.setter
    def prize_type(self, value):
        self._prize_type = value
    @property
    def shop_info(self):
        return self._shop_info

    @shop_info.setter
    def shop_info(self, value):
        self._shop_info = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value
    @property
    def voice_broadcast(self):
        return self._voice_broadcast

    @voice_broadcast.setter
    def voice_broadcast(self, value):
        self._voice_broadcast = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenContentIotCouponQueryResponse, self).parse_response_content(response_content)
        if 'btn_act' in response:
            self.btn_act = response['btn_act']
        if 'camp_id' in response:
            self.camp_id = response['camp_id']
        if 'component_template' in response:
            self.component_template = response['component_template']
        if 'content' in response:
            self.content = response['content']
        if 'item_type' in response:
            self.item_type = response['item_type']
        if 'nonempty_coupon_list' in response:
            self.nonempty_coupon_list = response['nonempty_coupon_list']
        if 'prize_type' in response:
            self.prize_type = response['prize_type']
        if 'shop_info' in response:
            self.shop_info = response['shop_info']
        if 'url' in response:
            self.url = response['url']
        if 'voice_broadcast' in response:
            self.voice_broadcast = response['voice_broadcast']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InfoCode(object):

    def __init__(self):
        self._risk_description = None
        self._risk_factor_code = None
        self._risk_factor_name = None
        self._risk_magnitude = None

    @property
    def risk_description(self):
        return self._risk_description

    @risk_description.setter
    def risk_description(self, value):
        self._risk_description = value
    @property
    def risk_factor_code(self):
        return self._risk_factor_code

    @risk_factor_code.setter
    def risk_factor_code(self, value):
        self._risk_factor_code = value
    @property
    def risk_factor_name(self):
        return self._risk_factor_name

    @risk_factor_name.setter
    def risk_factor_name(self, value):
        self._risk_factor_name = value
    @property
    def risk_magnitude(self):
        return self._risk_magnitude

    @risk_magnitude.setter
    def risk_magnitude(self, value):
        self._risk_magnitude = value


    def to_alipay_dict(self):
        params = dict()
        if self.risk_description:
            if hasattr(self.risk_description, 'to_alipay_dict'):
                params['risk_description'] = self.risk_description.to_alipay_dict()
            else:
                params['risk_description'] = self.risk_description
        if self.risk_factor_code:
            if hasattr(self.risk_factor_code, 'to_alipay_dict'):
                params['risk_factor_code'] = self.risk_factor_code.to_alipay_dict()
            else:
                params['risk_factor_code'] = self.risk_factor_code
        if self.risk_factor_name:
            if hasattr(self.risk_factor_name, 'to_alipay_dict'):
                params['risk_factor_name'] = self.risk_factor_name.to_alipay_dict()
            else:
                params['risk_factor_name'] = self.risk_factor_name
        if self.risk_magnitude:
            if hasattr(self.risk_magnitude, 'to_alipay_dict'):
                params['risk_magnitude'] = self.risk_magnitude.to_alipay_dict()
            else:
                params['risk_magnitude'] = self.risk_magnitude
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InfoCode()
        if 'risk_description' in d:
            o.risk_description = d['risk_description']
        if 'risk_factor_code' in d:
            o.risk_factor_code = d['risk_factor_code']
        if 'risk_factor_name' in d:
            o.risk_factor_name = d['risk_factor_name']
        if 'risk_magnitude' in d:
            o.risk_magnitude = d['risk_magnitude']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoDoctemplateSettingurlQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoDoctemplateSettingurlQueryResponse, self).__init__()
        self._setting_url = None

    @property
    def setting_url(self):
        return self._setting_url

    @setting_url.setter
    def setting_url(self, value):
        self._setting_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoDoctemplateSettingurlQueryResponse, self).parse_response_content(response_content)
        if 'setting_url' in response:
            self.setting_url = response['setting_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechAiCvRsXytileGetModel(object):

    def __init__(self):
        self._crow_type = None
        self._date = None
        self._index = None
        self._x = None
        self._y = None
        self._z = None

    @property
    def crow_type(self):
        return self._crow_type

    @crow_type.setter
    def crow_type(self, value):
        self._crow_type = value
    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def index(self):
        return self._index

    @index.setter
    def index(self, value):
        self._index = value
    @property
    def x(self):
        return self._x

    @x.setter
    def x(self, value):
        self._x = value
    @property
    def y(self):
        return self._y

    @y.setter
    def y(self, value):
        self._y = value
    @property
    def z(self):
        return self._z

    @z.setter
    def z(self, value):
        self._z = value


    def to_alipay_dict(self):
        params = dict()
        if self.crow_type:
            if hasattr(self.crow_type, 'to_alipay_dict'):
                params['crow_type'] = self.crow_type.to_alipay_dict()
            else:
                params['crow_type'] = self.crow_type
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        if self.index:
            if hasattr(self.index, 'to_alipay_dict'):
                params['index'] = self.index.to_alipay_dict()
            else:
                params['index'] = self.index
        if self.x:
            if hasattr(self.x, 'to_alipay_dict'):
                params['x'] = self.x.to_alipay_dict()
            else:
                params['x'] = self.x
        if self.y:
            if hasattr(self.y, 'to_alipay_dict'):
                params['y'] = self.y.to_alipay_dict()
            else:
                params['y'] = self.y
        if self.z:
            if hasattr(self.z, 'to_alipay_dict'):
                params['z'] = self.z.to_alipay_dict()
            else:
                params['z'] = self.z
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechAiCvRsXytileGetModel()
        if 'crow_type' in d:
            o.crow_type = d['crow_type']
        if 'date' in d:
            o.date = d['date']
        if 'index' in d:
            o.index = d['index']
        if 'x' in d:
            o.x = d['x']
        if 'y' in d:
            o.y = d['y']
        if 'z' in d:
            o.z = d['z']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BookTime(object):

    def __init__(self):
        self._time = None
        self._week = None

    @property
    def time(self):
        return self._time

    @time.setter
    def time(self, value):
        if isinstance(value, list):
            self._time = list()
            for i in value:
                self._time.append(i)
    @property
    def week(self):
        return self._week

    @week.setter
    def week(self, value):
        self._week = value


    def to_alipay_dict(self):
        params = dict()
        if self.time:
            if isinstance(self.time, list):
                for i in range(0, len(self.time)):
                    element = self.time[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.time[i] = element.to_alipay_dict()
            if hasattr(self.time, 'to_alipay_dict'):
                params['time'] = self.time.to_alipay_dict()
            else:
                params['time'] = self.time
        if self.week:
            if hasattr(self.week, 'to_alipay_dict'):
                params['week'] = self.week.to_alipay_dict()
            else:
                params['week'] = self.week
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BookTime()
        if 'time' in d:
            o.time = d['time']
        if 'week' in d:
            o.week = d['week']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AuthFieldSceneDTO import AuthFieldSceneDTO


class AlipayOpenAppApiSceneQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppApiSceneQueryResponse, self).__init__()
        self._auth_field_scene = None

    @property
    def auth_field_scene(self):
        return self._auth_field_scene

    @auth_field_scene.setter
    def auth_field_scene(self, value):
        if isinstance(value, list):
            self._auth_field_scene = list()
            for i in value:
                if isinstance(i, AuthFieldSceneDTO):
                    self._auth_field_scene.append(i)
                else:
                    self._auth_field_scene.append(AuthFieldSceneDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppApiSceneQueryResponse, self).parse_response_content(response_content)
        if 'auth_field_scene' in response:
            self.auth_field_scene = response['auth_field_scene']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayTradeCreditFinanceRefundResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeCreditFinanceRefundResponse, self).__init__()
        self._amount = None
        self._biz_no = None
        self._currency = None
        self._gmt_refund_pay = None
        self._out_request_no = None
        self._status = None
        self._trade_no = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def gmt_refund_pay(self):
        return self._gmt_refund_pay

    @gmt_refund_pay.setter
    def gmt_refund_pay(self, value):
        self._gmt_refund_pay = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeCreditFinanceRefundResponse, self).parse_response_content(response_content)
        if 'amount' in response:
            self.amount = response['amount']
        if 'biz_no' in response:
            self.biz_no = response['biz_no']
        if 'currency' in response:
            self.currency = response['currency']
        if 'gmt_refund_pay' in response:
            self.gmt_refund_pay = response['gmt_refund_pay']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'status' in response:
            self.status = response['status']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenApiResolutionMethod(object):

    def __init__(self):
        self._identifier = None
        self._requires_user_interaction = None
        self._type = None
        self._value = None

    @property
    def identifier(self):
        return self._identifier

    @identifier.setter
    def identifier(self, value):
        self._identifier = value
    @property
    def requires_user_interaction(self):
        return self._requires_user_interaction

    @requires_user_interaction.setter
    def requires_user_interaction(self, value):
        self._requires_user_interaction = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.identifier:
            if hasattr(self.identifier, 'to_alipay_dict'):
                params['identifier'] = self.identifier.to_alipay_dict()
            else:
                params['identifier'] = self.identifier
        if self.requires_user_interaction:
            if hasattr(self.requires_user_interaction, 'to_alipay_dict'):
                params['requires_user_interaction'] = self.requires_user_interaction.to_alipay_dict()
            else:
                params['requires_user_interaction'] = self.requires_user_interaction
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenApiResolutionMethod()
        if 'identifier' in d:
            o.identifier = d['identifier']
        if 'requires_user_interaction' in d:
            o.requires_user_interaction = d['requires_user_interaction']
        if 'type' in d:
            o.type = d['type']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LmDeleteItemList(object):

    def __init__(self):
        self._gmt_modified = None
        self._item_id = None
        self._lm_item_id = None
        self._sku_id_list = None

    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def lm_item_id(self):
        return self._lm_item_id

    @lm_item_id.setter
    def lm_item_id(self, value):
        self._lm_item_id = value
    @property
    def sku_id_list(self):
        return self._sku_id_list

    @sku_id_list.setter
    def sku_id_list(self, value):
        if isinstance(value, list):
            self._sku_id_list = list()
            for i in value:
                self._sku_id_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.lm_item_id:
            if hasattr(self.lm_item_id, 'to_alipay_dict'):
                params['lm_item_id'] = self.lm_item_id.to_alipay_dict()
            else:
                params['lm_item_id'] = self.lm_item_id
        if self.sku_id_list:
            if isinstance(self.sku_id_list, list):
                for i in range(0, len(self.sku_id_list)):
                    element = self.sku_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sku_id_list[i] = element.to_alipay_dict()
            if hasattr(self.sku_id_list, 'to_alipay_dict'):
                params['sku_id_list'] = self.sku_id_list.to_alipay_dict()
            else:
                params['sku_id_list'] = self.sku_id_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LmDeleteItemList()
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'lm_item_id' in d:
            o.lm_item_id = d['lm_item_id']
        if 'sku_id_list' in d:
            o.sku_id_list = d['sku_id_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ServiceOrderBaseInfo(object):

    def __init__(self):
        self._buyer_id = None
        self._buyer_name = None
        self._buyer_role_type = None
        self._expense_type = None
        self._expense_type_sub_category = None
        self._order_id = None
        self._order_status = None
        self._order_time = None
        self._related_service_id = None
        self._service_desc = None
        self._service_id = None
        self._service_name = None
        self._service_order_mode = None
        self._service_provider_id = None
        self._service_provider_name = None
        self._service_status = None
        self._service_type = None

    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def buyer_name(self):
        return self._buyer_name

    @buyer_name.setter
    def buyer_name(self, value):
        self._buyer_name = value
    @property
    def buyer_role_type(self):
        return self._buyer_role_type

    @buyer_role_type.setter
    def buyer_role_type(self, value):
        self._buyer_role_type = value
    @property
    def expense_type(self):
        return self._expense_type

    @expense_type.setter
    def expense_type(self, value):
        self._expense_type = value
    @property
    def expense_type_sub_category(self):
        return self._expense_type_sub_category

    @expense_type_sub_category.setter
    def expense_type_sub_category(self, value):
        self._expense_type_sub_category = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def order_time(self):
        return self._order_time

    @order_time.setter
    def order_time(self, value):
        self._order_time = value
    @property
    def related_service_id(self):
        return self._related_service_id

    @related_service_id.setter
    def related_service_id(self, value):
        self._related_service_id = value
    @property
    def service_desc(self):
        return self._service_desc

    @service_desc.setter
    def service_desc(self, value):
        self._service_desc = value
    @property
    def service_id(self):
        return self._service_id

    @service_id.setter
    def service_id(self, value):
        self._service_id = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value
    @property
    def service_order_mode(self):
        return self._service_order_mode

    @service_order_mode.setter
    def service_order_mode(self, value):
        self._service_order_mode = value
    @property
    def service_provider_id(self):
        return self._service_provider_id

    @service_provider_id.setter
    def service_provider_id(self, value):
        self._service_provider_id = value
    @property
    def service_provider_name(self):
        return self._service_provider_name

    @service_provider_name.setter
    def service_provider_name(self, value):
        self._service_provider_name = value
    @property
    def service_status(self):
        return self._service_status

    @service_status.setter
    def service_status(self, value):
        self._service_status = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer_id:
            if hasattr(self.buyer_id, 'to_alipay_dict'):
                params['buyer_id'] = self.buyer_id.to_alipay_dict()
            else:
                params['buyer_id'] = self.buyer_id
        if self.buyer_name:
            if hasattr(self.buyer_name, 'to_alipay_dict'):
                params['buyer_name'] = self.buyer_name.to_alipay_dict()
            else:
                params['buyer_name'] = self.buyer_name
        if self.buyer_role_type:
            if hasattr(self.buyer_role_type, 'to_alipay_dict'):
                params['buyer_role_type'] = self.buyer_role_type.to_alipay_dict()
            else:
                params['buyer_role_type'] = self.buyer_role_type
        if self.expense_type:
            if hasattr(self.expense_type, 'to_alipay_dict'):
                params['expense_type'] = self.expense_type.to_alipay_dict()
            else:
                params['expense_type'] = self.expense_type
        if self.expense_type_sub_category:
            if hasattr(self.expense_type_sub_category, 'to_alipay_dict'):
                params['expense_type_sub_category'] = self.expense_type_sub_category.to_alipay_dict()
            else:
                params['expense_type_sub_category'] = self.expense_type_sub_category
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.order_time:
            if hasattr(self.order_time, 'to_alipay_dict'):
                params['order_time'] = self.order_time.to_alipay_dict()
            else:
                params['order_time'] = self.order_time
        if self.related_service_id:
            if hasattr(self.related_service_id, 'to_alipay_dict'):
                params['related_service_id'] = self.related_service_id.to_alipay_dict()
            else:
                params['related_service_id'] = self.related_service_id
        if self.service_desc:
            if hasattr(self.service_desc, 'to_alipay_dict'):
                params['service_desc'] = self.service_desc.to_alipay_dict()
            else:
                params['service_desc'] = self.service_desc
        if self.service_id:
            if hasattr(self.service_id, 'to_alipay_dict'):
                params['service_id'] = self.service_id.to_alipay_dict()
            else:
                params['service_id'] = self.service_id
        if self.service_name:
            if hasattr(self.service_name, 'to_alipay_dict'):
                params['service_name'] = self.service_name.to_alipay_dict()
            else:
                params['service_name'] = self.service_name
        if self.service_order_mode:
            if hasattr(self.service_order_mode, 'to_alipay_dict'):
                params['service_order_mode'] = self.service_order_mode.to_alipay_dict()
            else:
                params['service_order_mode'] = self.service_order_mode
        if self.service_provider_id:
            if hasattr(self.service_provider_id, 'to_alipay_dict'):
                params['service_provider_id'] = self.service_provider_id.to_alipay_dict()
            else:
                params['service_provider_id'] = self.service_provider_id
        if self.service_provider_name:
            if hasattr(self.service_provider_name, 'to_alipay_dict'):
                params['service_provider_name'] = self.service_provider_name.to_alipay_dict()
            else:
                params['service_provider_name'] = self.service_provider_name
        if self.service_status:
            if hasattr(self.service_status, 'to_alipay_dict'):
                params['service_status'] = self.service_status.to_alipay_dict()
            else:
                params['service_status'] = self.service_status
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ServiceOrderBaseInfo()
        if 'buyer_id' in d:
            o.buyer_id = d['buyer_id']
        if 'buyer_name' in d:
            o.buyer_name = d['buyer_name']
        if 'buyer_role_type' in d:
            o.buyer_role_type = d['buyer_role_type']
        if 'expense_type' in d:
            o.expense_type = d['expense_type']
        if 'expense_type_sub_category' in d:
            o.expense_type_sub_category = d['expense_type_sub_category']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'order_time' in d:
            o.order_time = d['order_time']
        if 'related_service_id' in d:
            o.related_service_id = d['related_service_id']
        if 'service_desc' in d:
            o.service_desc = d['service_desc']
        if 'service_id' in d:
            o.service_id = d['service_id']
        if 'service_name' in d:
            o.service_name = d['service_name']
        if 'service_order_mode' in d:
            o.service_order_mode = d['service_order_mode']
        if 'service_provider_id' in d:
            o.service_provider_id = d['service_provider_id']
        if 'service_provider_name' in d:
            o.service_provider_name = d['service_provider_name']
        if 'service_status' in d:
            o.service_status = d['service_status']
        if 'service_type' in d:
            o.service_type = d['service_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserElectronicidOutermerchantbarcodeCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserElectronicidOutermerchantbarcodeCreateResponse, self).__init__()
        self._barcode = None
        self._image_url = None

    @property
    def barcode(self):
        return self._barcode

    @barcode.setter
    def barcode(self, value):
        self._barcode = value
    @property
    def image_url(self):
        return self._image_url

    @image_url.setter
    def image_url(self, value):
        self._image_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserElectronicidOutermerchantbarcodeCreateResponse, self).parse_response_content(response_content)
        if 'barcode' in response:
            self.barcode = response['barcode']
        if 'image_url' in response:
            self.image_url = response['image_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AmountWf import AmountWf
from alipay.aop.api.domain.AmountWf import AmountWf


class BillDetailResult(object):

    def __init__(self):
        self._balanceamt = None
        self._billno = None
        self._duedate = None
        self._encashamt = None
        self._startdate = None
        self._status = None

    @property
    def balanceamt(self):
        return self._balanceamt

    @balanceamt.setter
    def balanceamt(self, value):
        if isinstance(value, AmountWf):
            self._balanceamt = value
        else:
            self._balanceamt = AmountWf.from_alipay_dict(value)
    @property
    def billno(self):
        return self._billno

    @billno.setter
    def billno(self, value):
        self._billno = value
    @property
    def duedate(self):
        return self._duedate

    @duedate.setter
    def duedate(self, value):
        self._duedate = value
    @property
    def encashamt(self):
        return self._encashamt

    @encashamt.setter
    def encashamt(self, value):
        if isinstance(value, AmountWf):
            self._encashamt = value
        else:
            self._encashamt = AmountWf.from_alipay_dict(value)
    @property
    def startdate(self):
        return self._startdate

    @startdate.setter
    def startdate(self, value):
        self._startdate = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.balanceamt:
            if hasattr(self.balanceamt, 'to_alipay_dict'):
                params['balanceamt'] = self.balanceamt.to_alipay_dict()
            else:
                params['balanceamt'] = self.balanceamt
        if self.billno:
            if hasattr(self.billno, 'to_alipay_dict'):
                params['billno'] = self.billno.to_alipay_dict()
            else:
                params['billno'] = self.billno
        if self.duedate:
            if hasattr(self.duedate, 'to_alipay_dict'):
                params['duedate'] = self.duedate.to_alipay_dict()
            else:
                params['duedate'] = self.duedate
        if self.encashamt:
            if hasattr(self.encashamt, 'to_alipay_dict'):
                params['encashamt'] = self.encashamt.to_alipay_dict()
            else:
                params['encashamt'] = self.encashamt
        if self.startdate:
            if hasattr(self.startdate, 'to_alipay_dict'):
                params['startdate'] = self.startdate.to_alipay_dict()
            else:
                params['startdate'] = self.startdate
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BillDetailResult()
        if 'balanceamt' in d:
            o.balanceamt = d['balanceamt']
        if 'billno' in d:
            o.billno = d['billno']
        if 'duedate' in d:
            o.duedate = d['duedate']
        if 'encashamt' in d:
            o.encashamt = d['encashamt']
        if 'startdate' in d:
            o.startdate = d['startdate']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SearchBoxAppInfo import SearchBoxAppInfo
from alipay.aop.api.domain.SearchBoxServiceInfo import SearchBoxServiceInfo


class AlipayOpenSearchBoxApplyModel(object):

    def __init__(self):
        self._area_keywords = None
        self._box_desc = None
        self._brand_id = None
        self._business_benefit_switch = None
        self._business_district_ids = None
        self._custom_keywords = None
        self._image_id = None
        self._image_name = None
        self._merchant_id = None
        self._related_accounts = None
        self._service_infos = None
        self._target_appid = None

    @property
    def area_keywords(self):
        return self._area_keywords

    @area_keywords.setter
    def area_keywords(self, value):
        if isinstance(value, list):
            self._area_keywords = list()
            for i in value:
                self._area_keywords.append(i)
    @property
    def box_desc(self):
        return self._box_desc

    @box_desc.setter
    def box_desc(self, value):
        self._box_desc = value
    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def business_benefit_switch(self):
        return self._business_benefit_switch

    @business_benefit_switch.setter
    def business_benefit_switch(self, value):
        self._business_benefit_switch = value
    @property
    def business_district_ids(self):
        return self._business_district_ids

    @business_district_ids.setter
    def business_district_ids(self, value):
        if isinstance(value, list):
            self._business_district_ids = list()
            for i in value:
                self._business_district_ids.append(i)
    @property
    def custom_keywords(self):
        return self._custom_keywords

    @custom_keywords.setter
    def custom_keywords(self, value):
        if isinstance(value, list):
            self._custom_keywords = list()
            for i in value:
                self._custom_keywords.append(i)
    @property
    def image_id(self):
        return self._image_id

    @image_id.setter
    def image_id(self, value):
        self._image_id = value
    @property
    def image_name(self):
        return self._image_name

    @image_name.setter
    def image_name(self, value):
        self._image_name = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def related_accounts(self):
        return self._related_accounts

    @related_accounts.setter
    def related_accounts(self, value):
        if isinstance(value, list):
            self._related_accounts = list()
            for i in value:
                if isinstance(i, SearchBoxAppInfo):
                    self._related_accounts.append(i)
                else:
                    self._related_accounts.append(SearchBoxAppInfo.from_alipay_dict(i))
    @property
    def service_infos(self):
        return self._service_infos

    @service_infos.setter
    def service_infos(self, value):
        if isinstance(value, list):
            self._service_infos = list()
            for i in value:
                if isinstance(i, SearchBoxServiceInfo):
                    self._service_infos.append(i)
                else:
                    self._service_infos.append(SearchBoxServiceInfo.from_alipay_dict(i))
    @property
    def target_appid(self):
        return self._target_appid

    @target_appid.setter
    def target_appid(self, value):
        self._target_appid = value


    def to_alipay_dict(self):
        params = dict()
        if self.area_keywords:
            if isinstance(self.area_keywords, list):
                for i in range(0, len(self.area_keywords)):
                    element = self.area_keywords[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.area_keywords[i] = element.to_alipay_dict()
            if hasattr(self.area_keywords, 'to_alipay_dict'):
                params['area_keywords'] = self.area_keywords.to_alipay_dict()
            else:
                params['area_keywords'] = self.area_keywords
        if self.box_desc:
            if hasattr(self.box_desc, 'to_alipay_dict'):
                params['box_desc'] = self.box_desc.to_alipay_dict()
            else:
                params['box_desc'] = self.box_desc
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.business_benefit_switch:
            if hasattr(self.business_benefit_switch, 'to_alipay_dict'):
                params['business_benefit_switch'] = self.business_benefit_switch.to_alipay_dict()
            else:
                params['business_benefit_switch'] = self.business_benefit_switch
        if self.business_district_ids:
            if isinstance(self.business_district_ids, list):
                for i in range(0, len(self.business_district_ids)):
                    element = self.business_district_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.business_district_ids[i] = element.to_alipay_dict()
            if hasattr(self.business_district_ids, 'to_alipay_dict'):
                params['business_district_ids'] = self.business_district_ids.to_alipay_dict()
            else:
                params['business_district_ids'] = self.business_district_ids
        if self.custom_keywords:
            if isinstance(self.custom_keywords, list):
                for i in range(0, len(self.custom_keywords)):
                    element = self.custom_keywords[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.custom_keywords[i] = element.to_alipay_dict()
            if hasattr(self.custom_keywords, 'to_alipay_dict'):
                params['custom_keywords'] = self.custom_keywords.to_alipay_dict()
            else:
                params['custom_keywords'] = self.custom_keywords
        if self.image_id:
            if hasattr(self.image_id, 'to_alipay_dict'):
                params['image_id'] = self.image_id.to_alipay_dict()
            else:
                params['image_id'] = self.image_id
        if self.image_name:
            if hasattr(self.image_name, 'to_alipay_dict'):
                params['image_name'] = self.image_name.to_alipay_dict()
            else:
                params['image_name'] = self.image_name
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.related_accounts:
            if isinstance(self.related_accounts, list):
                for i in range(0, len(self.related_accounts)):
                    element = self.related_accounts[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.related_accounts[i] = element.to_alipay_dict()
            if hasattr(self.related_accounts, 'to_alipay_dict'):
                params['related_accounts'] = self.related_accounts.to_alipay_dict()
            else:
                params['related_accounts'] = self.related_accounts
        if self.service_infos:
            if isinstance(self.service_infos, list):
                for i in range(0, len(self.service_infos)):
                    element = self.service_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.service_infos[i] = element.to_alipay_dict()
            if hasattr(self.service_infos, 'to_alipay_dict'):
                params['service_infos'] = self.service_infos.to_alipay_dict()
            else:
                params['service_infos'] = self.service_infos
        if self.target_appid:
            if hasattr(self.target_appid, 'to_alipay_dict'):
                params['target_appid'] = self.target_appid.to_alipay_dict()
            else:
                params['target_appid'] = self.target_appid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenSearchBoxApplyModel()
        if 'area_keywords' in d:
            o.area_keywords = d['area_keywords']
        if 'box_desc' in d:
            o.box_desc = d['box_desc']
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'business_benefit_switch' in d:
            o.business_benefit_switch = d['business_benefit_switch']
        if 'business_district_ids' in d:
            o.business_district_ids = d['business_district_ids']
        if 'custom_keywords' in d:
            o.custom_keywords = d['custom_keywords']
        if 'image_id' in d:
            o.image_id = d['image_id']
        if 'image_name' in d:
            o.image_name = d['image_name']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'related_accounts' in d:
            o.related_accounts = d['related_accounts']
        if 'service_infos' in d:
            o.service_infos = d['service_infos']
        if 'target_appid' in d:
            o.target_appid = d['target_appid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MerchantActivityVoucherInfo(object):

    def __init__(self):
        self._logo = None
        self._sub_title = None
        self._user_introductions = None
        self._valid_days_range_from = None
        self._valid_days_range_to = None
        self._valid_time_range_from = None
        self._valid_time_range_to = None
        self._valid_time_type = None

    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def sub_title(self):
        return self._sub_title

    @sub_title.setter
    def sub_title(self, value):
        self._sub_title = value
    @property
    def user_introductions(self):
        return self._user_introductions

    @user_introductions.setter
    def user_introductions(self, value):
        self._user_introductions = value
    @property
    def valid_days_range_from(self):
        return self._valid_days_range_from

    @valid_days_range_from.setter
    def valid_days_range_from(self, value):
        self._valid_days_range_from = value
    @property
    def valid_days_range_to(self):
        return self._valid_days_range_to

    @valid_days_range_to.setter
    def valid_days_range_to(self, value):
        self._valid_days_range_to = value
    @property
    def valid_time_range_from(self):
        return self._valid_time_range_from

    @valid_time_range_from.setter
    def valid_time_range_from(self, value):
        self._valid_time_range_from = value
    @property
    def valid_time_range_to(self):
        return self._valid_time_range_to

    @valid_time_range_to.setter
    def valid_time_range_to(self, value):
        self._valid_time_range_to = value
    @property
    def valid_time_type(self):
        return self._valid_time_type

    @valid_time_type.setter
    def valid_time_type(self, value):
        self._valid_time_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.sub_title:
            if hasattr(self.sub_title, 'to_alipay_dict'):
                params['sub_title'] = self.sub_title.to_alipay_dict()
            else:
                params['sub_title'] = self.sub_title
        if self.user_introductions:
            if hasattr(self.user_introductions, 'to_alipay_dict'):
                params['user_introductions'] = self.user_introductions.to_alipay_dict()
            else:
                params['user_introductions'] = self.user_introductions
        if self.valid_days_range_from:
            if hasattr(self.valid_days_range_from, 'to_alipay_dict'):
                params['valid_days_range_from'] = self.valid_days_range_from.to_alipay_dict()
            else:
                params['valid_days_range_from'] = self.valid_days_range_from
        if self.valid_days_range_to:
            if hasattr(self.valid_days_range_to, 'to_alipay_dict'):
                params['valid_days_range_to'] = self.valid_days_range_to.to_alipay_dict()
            else:
                params['valid_days_range_to'] = self.valid_days_range_to
        if self.valid_time_range_from:
            if hasattr(self.valid_time_range_from, 'to_alipay_dict'):
                params['valid_time_range_from'] = self.valid_time_range_from.to_alipay_dict()
            else:
                params['valid_time_range_from'] = self.valid_time_range_from
        if self.valid_time_range_to:
            if hasattr(self.valid_time_range_to, 'to_alipay_dict'):
                params['valid_time_range_to'] = self.valid_time_range_to.to_alipay_dict()
            else:
                params['valid_time_range_to'] = self.valid_time_range_to
        if self.valid_time_type:
            if hasattr(self.valid_time_type, 'to_alipay_dict'):
                params['valid_time_type'] = self.valid_time_type.to_alipay_dict()
            else:
                params['valid_time_type'] = self.valid_time_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MerchantActivityVoucherInfo()
        if 'logo' in d:
            o.logo = d['logo']
        if 'sub_title' in d:
            o.sub_title = d['sub_title']
        if 'user_introductions' in d:
            o.user_introductions = d['user_introductions']
        if 'valid_days_range_from' in d:
            o.valid_days_range_from = d['valid_days_range_from']
        if 'valid_days_range_to' in d:
            o.valid_days_range_to = d['valid_days_range_to']
        if 'valid_time_range_from' in d:
            o.valid_time_range_from = d['valid_time_range_from']
        if 'valid_time_range_to' in d:
            o.valid_time_range_to = d['valid_time_range_to']
        if 'valid_time_type' in d:
            o.valid_time_type = d['valid_time_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenServicemarketYcstestQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenServicemarketYcstestQueryResponse, self).__init__()
        self._out_1 = None
        self._out_2 = None

    @property
    def out_1(self):
        return self._out_1

    @out_1.setter
    def out_1(self, value):
        self._out_1 = value
    @property
    def out_2(self):
        return self._out_2

    @out_2.setter
    def out_2(self, value):
        self._out_2 = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenServicemarketYcstestQueryResponse, self).parse_response_content(response_content)
        if 'out_1' in response:
            self.out_1 = response['out_1']
        if 'out_2' in response:
            self.out_2 = response['out_2']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceOperationRecyclecampBenefitSyncModel(object):

    def __init__(self):
        self._outer_benefit_id = None
        self._remain_inventory = None
        self._sync_timestamp = None
        self._sync_type = None

    @property
    def outer_benefit_id(self):
        return self._outer_benefit_id

    @outer_benefit_id.setter
    def outer_benefit_id(self, value):
        self._outer_benefit_id = value
    @property
    def remain_inventory(self):
        return self._remain_inventory

    @remain_inventory.setter
    def remain_inventory(self, value):
        self._remain_inventory = value
    @property
    def sync_timestamp(self):
        return self._sync_timestamp

    @sync_timestamp.setter
    def sync_timestamp(self, value):
        self._sync_timestamp = value
    @property
    def sync_type(self):
        return self._sync_type

    @sync_type.setter
    def sync_type(self, value):
        self._sync_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.outer_benefit_id:
            if hasattr(self.outer_benefit_id, 'to_alipay_dict'):
                params['outer_benefit_id'] = self.outer_benefit_id.to_alipay_dict()
            else:
                params['outer_benefit_id'] = self.outer_benefit_id
        if self.remain_inventory:
            if hasattr(self.remain_inventory, 'to_alipay_dict'):
                params['remain_inventory'] = self.remain_inventory.to_alipay_dict()
            else:
                params['remain_inventory'] = self.remain_inventory
        if self.sync_timestamp:
            if hasattr(self.sync_timestamp, 'to_alipay_dict'):
                params['sync_timestamp'] = self.sync_timestamp.to_alipay_dict()
            else:
                params['sync_timestamp'] = self.sync_timestamp
        if self.sync_type:
            if hasattr(self.sync_type, 'to_alipay_dict'):
                params['sync_type'] = self.sync_type.to_alipay_dict()
            else:
                params['sync_type'] = self.sync_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationRecyclecampBenefitSyncModel()
        if 'outer_benefit_id' in d:
            o.outer_benefit_id = d['outer_benefit_id']
        if 'remain_inventory' in d:
            o.remain_inventory = d['remain_inventory']
        if 'sync_timestamp' in d:
            o.sync_timestamp = d['sync_timestamp']
        if 'sync_type' in d:
            o.sync_type = d['sync_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MaterialField(object):

    def __init__(self):
        self._field_name = None
        self._field_value = None

    @property
    def field_name(self):
        return self._field_name

    @field_name.setter
    def field_name(self, value):
        self._field_name = value
    @property
    def field_value(self):
        return self._field_value

    @field_value.setter
    def field_value(self, value):
        if isinstance(value, list):
            self._field_value = list()
            for i in value:
                self._field_value.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.field_name:
            if hasattr(self.field_name, 'to_alipay_dict'):
                params['field_name'] = self.field_name.to_alipay_dict()
            else:
                params['field_name'] = self.field_name
        if self.field_value:
            if isinstance(self.field_value, list):
                for i in range(0, len(self.field_value)):
                    element = self.field_value[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.field_value[i] = element.to_alipay_dict()
            if hasattr(self.field_value, 'to_alipay_dict'):
                params['field_value'] = self.field_value.to_alipay_dict()
            else:
                params['field_value'] = self.field_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MaterialField()
        if 'field_name' in d:
            o.field_name = d['field_name']
        if 'field_value' in d:
            o.field_value = d['field_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceReceiptInvalidModel(object):

    def __init__(self):
        self._alipay_open_id = None
        self._alipay_uid = None
        self._invalid_date = None
        self._out_biz_no = None
        self._trade_no = None

    @property
    def alipay_open_id(self):
        return self._alipay_open_id

    @alipay_open_id.setter
    def alipay_open_id(self, value):
        self._alipay_open_id = value
    @property
    def alipay_uid(self):
        return self._alipay_uid

    @alipay_uid.setter
    def alipay_uid(self, value):
        self._alipay_uid = value
    @property
    def invalid_date(self):
        return self._invalid_date

    @invalid_date.setter
    def invalid_date(self, value):
        self._invalid_date = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_open_id:
            if hasattr(self.alipay_open_id, 'to_alipay_dict'):
                params['alipay_open_id'] = self.alipay_open_id.to_alipay_dict()
            else:
                params['alipay_open_id'] = self.alipay_open_id
        if self.alipay_uid:
            if hasattr(self.alipay_uid, 'to_alipay_dict'):
                params['alipay_uid'] = self.alipay_uid.to_alipay_dict()
            else:
                params['alipay_uid'] = self.alipay_uid
        if self.invalid_date:
            if hasattr(self.invalid_date, 'to_alipay_dict'):
                params['invalid_date'] = self.invalid_date.to_alipay_dict()
            else:
                params['invalid_date'] = self.invalid_date
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceReceiptInvalidModel()
        if 'alipay_open_id' in d:
            o.alipay_open_id = d['alipay_open_id']
        if 'alipay_uid' in d:
            o.alipay_uid = d['alipay_uid']
        if 'invalid_date' in d:
            o.invalid_date = d['invalid_date']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ServeParamInfo import ServeParamInfo


class SlmMethodInfo(object):

    def __init__(self):
        self._method_desc = None
        self._method_name = None
        self._param_info_list = None

    @property
    def method_desc(self):
        return self._method_desc

    @method_desc.setter
    def method_desc(self, value):
        self._method_desc = value
    @property
    def method_name(self):
        return self._method_name

    @method_name.setter
    def method_name(self, value):
        self._method_name = value
    @property
    def param_info_list(self):
        return self._param_info_list

    @param_info_list.setter
    def param_info_list(self, value):
        if isinstance(value, ServeParamInfo):
            self._param_info_list = value
        else:
            self._param_info_list = ServeParamInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.method_desc:
            if hasattr(self.method_desc, 'to_alipay_dict'):
                params['method_desc'] = self.method_desc.to_alipay_dict()
            else:
                params['method_desc'] = self.method_desc
        if self.method_name:
            if hasattr(self.method_name, 'to_alipay_dict'):
                params['method_name'] = self.method_name.to_alipay_dict()
            else:
                params['method_name'] = self.method_name
        if self.param_info_list:
            if hasattr(self.param_info_list, 'to_alipay_dict'):
                params['param_info_list'] = self.param_info_list.to_alipay_dict()
            else:
                params['param_info_list'] = self.param_info_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SlmMethodInfo()
        if 'method_desc' in d:
            o.method_desc = d['method_desc']
        if 'method_name' in d:
            o.method_name = d['method_name']
        if 'param_info_list' in d:
            o.param_info_list = d['param_info_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsAutoAutoinsprodCommonNotifyModel(object):

    def __init__(self):
        self._biz_data = None
        self._biz_type = None

    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsAutoAutoinsprodCommonNotifyModel()
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppCommonBillQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppCommonBillQueryResponse, self).__init__()
        self._bill_key = None
        self._bill_no = None
        self._charge_inst = None
        self._chargeoff_inst = None
        self._extend_field = None
        self._gmt_create = None
        self._gmt_pay = None
        self._status = None

    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def chargeoff_inst(self):
        return self._chargeoff_inst

    @chargeoff_inst.setter
    def chargeoff_inst(self, value):
        self._chargeoff_inst = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_pay(self):
        return self._gmt_pay

    @gmt_pay.setter
    def gmt_pay(self, value):
        self._gmt_pay = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppCommonBillQueryResponse, self).parse_response_content(response_content)
        if 'bill_key' in response:
            self.bill_key = response['bill_key']
        if 'bill_no' in response:
            self.bill_no = response['bill_no']
        if 'charge_inst' in response:
            self.charge_inst = response['charge_inst']
        if 'chargeoff_inst' in response:
            self.chargeoff_inst = response['chargeoff_inst']
        if 'extend_field' in response:
            self.extend_field = response['extend_field']
        if 'gmt_create' in response:
            self.gmt_create = response['gmt_create']
        if 'gmt_pay' in response:
            self.gmt_pay = response['gmt_pay']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PayerAccountDTO import PayerAccountDTO


class FundPlanDTO(object):

    def __init__(self):
        self._account_id = None
        self._amount = None
        self._calendar_type = None
        self._creator_id = None
        self._creator_open_id = None
        self._date = None
        self._end_date = None
        self._fund_plan_id = None
        self._incremental_amount = None
        self._initial_amount = None
        self._next_execution = None
        self._out_biz_no = None
        self._payer_account = None
        self._plan_mode = None
        self._plan_times = None
        self._remark = None
        self._start_date = None
        self._status = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def calendar_type(self):
        return self._calendar_type

    @calendar_type.setter
    def calendar_type(self, value):
        self._calendar_type = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def creator_open_id(self):
        return self._creator_open_id

    @creator_open_id.setter
    def creator_open_id(self, value):
        self._creator_open_id = value
    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def fund_plan_id(self):
        return self._fund_plan_id

    @fund_plan_id.setter
    def fund_plan_id(self, value):
        self._fund_plan_id = value
    @property
    def incremental_amount(self):
        return self._incremental_amount

    @incremental_amount.setter
    def incremental_amount(self, value):
        self._incremental_amount = value
    @property
    def initial_amount(self):
        return self._initial_amount

    @initial_amount.setter
    def initial_amount(self, value):
        self._initial_amount = value
    @property
    def next_execution(self):
        return self._next_execution

    @next_execution.setter
    def next_execution(self, value):
        self._next_execution = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def payer_account(self):
        return self._payer_account

    @payer_account.setter
    def payer_account(self, value):
        if isinstance(value, PayerAccountDTO):
            self._payer_account = value
        else:
            self._payer_account = PayerAccountDTO.from_alipay_dict(value)
    @property
    def plan_mode(self):
        return self._plan_mode

    @plan_mode.setter
    def plan_mode(self, value):
        self._plan_mode = value
    @property
    def plan_times(self):
        return self._plan_times

    @plan_times.setter
    def plan_times(self, value):
        self._plan_times = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.calendar_type:
            if hasattr(self.calendar_type, 'to_alipay_dict'):
                params['calendar_type'] = self.calendar_type.to_alipay_dict()
            else:
                params['calendar_type'] = self.calendar_type
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.creator_open_id:
            if hasattr(self.creator_open_id, 'to_alipay_dict'):
                params['creator_open_id'] = self.creator_open_id.to_alipay_dict()
            else:
                params['creator_open_id'] = self.creator_open_id
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.fund_plan_id:
            if hasattr(self.fund_plan_id, 'to_alipay_dict'):
                params['fund_plan_id'] = self.fund_plan_id.to_alipay_dict()
            else:
                params['fund_plan_id'] = self.fund_plan_id
        if self.incremental_amount:
            if hasattr(self.incremental_amount, 'to_alipay_dict'):
                params['incremental_amount'] = self.incremental_amount.to_alipay_dict()
            else:
                params['incremental_amount'] = self.incremental_amount
        if self.initial_amount:
            if hasattr(self.initial_amount, 'to_alipay_dict'):
                params['initial_amount'] = self.initial_amount.to_alipay_dict()
            else:
                params['initial_amount'] = self.initial_amount
        if self.next_execution:
            if hasattr(self.next_execution, 'to_alipay_dict'):
                params['next_execution'] = self.next_execution.to_alipay_dict()
            else:
                params['next_execution'] = self.next_execution
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.payer_account:
            if hasattr(self.payer_account, 'to_alipay_dict'):
                params['payer_account'] = self.payer_account.to_alipay_dict()
            else:
                params['payer_account'] = self.payer_account
        if self.plan_mode:
            if hasattr(self.plan_mode, 'to_alipay_dict'):
                params['plan_mode'] = self.plan_mode.to_alipay_dict()
            else:
                params['plan_mode'] = self.plan_mode
        if self.plan_times:
            if hasattr(self.plan_times, 'to_alipay_dict'):
                params['plan_times'] = self.plan_times.to_alipay_dict()
            else:
                params['plan_times'] = self.plan_times
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FundPlanDTO()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'amount' in d:
            o.amount = d['amount']
        if 'calendar_type' in d:
            o.calendar_type = d['calendar_type']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'creator_open_id' in d:
            o.creator_open_id = d['creator_open_id']
        if 'date' in d:
            o.date = d['date']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'fund_plan_id' in d:
            o.fund_plan_id = d['fund_plan_id']
        if 'incremental_amount' in d:
            o.incremental_amount = d['incremental_amount']
        if 'initial_amount' in d:
            o.initial_amount = d['initial_amount']
        if 'next_execution' in d:
            o.next_execution = d['next_execution']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'payer_account' in d:
            o.payer_account = d['payer_account']
        if 'plan_mode' in d:
            o.plan_mode = d['plan_mode']
        if 'plan_times' in d:
            o.plan_times = d['plan_times']
        if 'remark' in d:
            o.remark = d['remark']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BaseInfo import BaseInfo
from alipay.aop.api.domain.BusinessLicenceInfo import BusinessLicenceInfo
from alipay.aop.api.domain.OperatorInfo import OperatorInfo
from alipay.aop.api.domain.PersonnalBankAccountInfo import PersonnalBankAccountInfo
from alipay.aop.api.domain.ShopInfo import ShopInfo


class AntMerchantExpandPersonalApplyModel(object):

    def __init__(self):
        self._base_info = None
        self._business_license_info = None
        self._login_id = None
        self._operator_info = None
        self._out_biz_no = None
        self._personal_bank_account_info = None
        self._shop_info = None

    @property
    def base_info(self):
        return self._base_info

    @base_info.setter
    def base_info(self, value):
        if isinstance(value, BaseInfo):
            self._base_info = value
        else:
            self._base_info = BaseInfo.from_alipay_dict(value)
    @property
    def business_license_info(self):
        return self._business_license_info

    @business_license_info.setter
    def business_license_info(self, value):
        if isinstance(value, BusinessLicenceInfo):
            self._business_license_info = value
        else:
            self._business_license_info = BusinessLicenceInfo.from_alipay_dict(value)
    @property
    def login_id(self):
        return self._login_id

    @login_id.setter
    def login_id(self, value):
        self._login_id = value
    @property
    def operator_info(self):
        return self._operator_info

    @operator_info.setter
    def operator_info(self, value):
        if isinstance(value, OperatorInfo):
            self._operator_info = value
        else:
            self._operator_info = OperatorInfo.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def personal_bank_account_info(self):
        return self._personal_bank_account_info

    @personal_bank_account_info.setter
    def personal_bank_account_info(self, value):
        if isinstance(value, PersonnalBankAccountInfo):
            self._personal_bank_account_info = value
        else:
            self._personal_bank_account_info = PersonnalBankAccountInfo.from_alipay_dict(value)
    @property
    def shop_info(self):
        return self._shop_info

    @shop_info.setter
    def shop_info(self, value):
        if isinstance(value, ShopInfo):
            self._shop_info = value
        else:
            self._shop_info = ShopInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.base_info:
            if hasattr(self.base_info, 'to_alipay_dict'):
                params['base_info'] = self.base_info.to_alipay_dict()
            else:
                params['base_info'] = self.base_info
        if self.business_license_info:
            if hasattr(self.business_license_info, 'to_alipay_dict'):
                params['business_license_info'] = self.business_license_info.to_alipay_dict()
            else:
                params['business_license_info'] = self.business_license_info
        if self.login_id:
            if hasattr(self.login_id, 'to_alipay_dict'):
                params['login_id'] = self.login_id.to_alipay_dict()
            else:
                params['login_id'] = self.login_id
        if self.operator_info:
            if hasattr(self.operator_info, 'to_alipay_dict'):
                params['operator_info'] = self.operator_info.to_alipay_dict()
            else:
                params['operator_info'] = self.operator_info
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.personal_bank_account_info:
            if hasattr(self.personal_bank_account_info, 'to_alipay_dict'):
                params['personal_bank_account_info'] = self.personal_bank_account_info.to_alipay_dict()
            else:
                params['personal_bank_account_info'] = self.personal_bank_account_info
        if self.shop_info:
            if hasattr(self.shop_info, 'to_alipay_dict'):
                params['shop_info'] = self.shop_info.to_alipay_dict()
            else:
                params['shop_info'] = self.shop_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandPersonalApplyModel()
        if 'base_info' in d:
            o.base_info = d['base_info']
        if 'business_license_info' in d:
            o.business_license_info = d['business_license_info']
        if 'login_id' in d:
            o.login_id = d['login_id']
        if 'operator_info' in d:
            o.operator_info = d['operator_info']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'personal_bank_account_info' in d:
            o.personal_bank_account_info = d['personal_bank_account_info']
        if 'shop_info' in d:
            o.shop_info = d['shop_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AppAttribute import AppAttribute
from alipay.aop.api.domain.ServiceUrl import ServiceUrl


class AlipayOpenAppAppcontentFunctionQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppAppcontentFunctionQueryResponse, self).__init__()
        self._area_codes = None
        self._audit_status = None
        self._category_attributes = None
        self._category_ids = None
        self._icon = None
        self._key_words = None
        self._major_status = None
        self._reject_reason = None
        self._service_code = None
        self._service_name = None
        self._service_time_end = None
        self._service_time_start = None
        self._service_urls = None
        self._short_desc = None

    @property
    def area_codes(self):
        return self._area_codes

    @area_codes.setter
    def area_codes(self, value):
        if isinstance(value, list):
            self._area_codes = list()
            for i in value:
                self._area_codes.append(i)
    @property
    def audit_status(self):
        return self._audit_status

    @audit_status.setter
    def audit_status(self, value):
        self._audit_status = value
    @property
    def category_attributes(self):
        return self._category_attributes

    @category_attributes.setter
    def category_attributes(self, value):
        if isinstance(value, list):
            self._category_attributes = list()
            for i in value:
                if isinstance(i, AppAttribute):
                    self._category_attributes.append(i)
                else:
                    self._category_attributes.append(AppAttribute.from_alipay_dict(i))
    @property
    def category_ids(self):
        return self._category_ids

    @category_ids.setter
    def category_ids(self, value):
        if isinstance(value, list):
            self._category_ids = list()
            for i in value:
                self._category_ids.append(i)
    @property
    def icon(self):
        return self._icon

    @icon.setter
    def icon(self, value):
        self._icon = value
    @property
    def key_words(self):
        return self._key_words

    @key_words.setter
    def key_words(self, value):
        if isinstance(value, list):
            self._key_words = list()
            for i in value:
                self._key_words.append(i)
    @property
    def major_status(self):
        return self._major_status

    @major_status.setter
    def major_status(self, value):
        self._major_status = value
    @property
    def reject_reason(self):
        return self._reject_reason

    @reject_reason.setter
    def reject_reason(self, value):
        self._reject_reason = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value
    @property
    def service_time_end(self):
        return self._service_time_end

    @service_time_end.setter
    def service_time_end(self, value):
        self._service_time_end = value
    @property
    def service_time_start(self):
        return self._service_time_start

    @service_time_start.setter
    def service_time_start(self, value):
        self._service_time_start = value
    @property
    def service_urls(self):
        return self._service_urls

    @service_urls.setter
    def service_urls(self, value):
        if isinstance(value, list):
            self._service_urls = list()
            for i in value:
                if isinstance(i, ServiceUrl):
                    self._service_urls.append(i)
                else:
                    self._service_urls.append(ServiceUrl.from_alipay_dict(i))
    @property
    def short_desc(self):
        return self._short_desc

    @short_desc.setter
    def short_desc(self, value):
        self._short_desc = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppAppcontentFunctionQueryResponse, self).parse_response_content(response_content)
        if 'area_codes' in response:
            self.area_codes = response['area_codes']
        if 'audit_status' in response:
            self.audit_status = response['audit_status']
        if 'category_attributes' in response:
            self.category_attributes = response['category_attributes']
        if 'category_ids' in response:
            self.category_ids = response['category_ids']
        if 'icon' in response:
            self.icon = response['icon']
        if 'key_words' in response:
            self.key_words = response['key_words']
        if 'major_status' in response:
            self.major_status = response['major_status']
        if 'reject_reason' in response:
            self.reject_reason = response['reject_reason']
        if 'service_code' in response:
            self.service_code = response['service_code']
        if 'service_name' in response:
            self.service_name = response['service_name']
        if 'service_time_end' in response:
            self.service_time_end = response['service_time_end']
        if 'service_time_start' in response:
            self.service_time_start = response['service_time_start']
        if 'service_urls' in response:
            self.service_urls = response['service_urls']
        if 'short_desc' in response:
            self.short_desc = response['short_desc']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RecruitContentAppItem import RecruitContentAppItem


class RecruitEnrollContent(object):

    def __init__(self):
        self._app_items = None

    @property
    def app_items(self):
        return self._app_items

    @app_items.setter
    def app_items(self, value):
        if isinstance(value, list):
            self._app_items = list()
            for i in value:
                if isinstance(i, RecruitContentAppItem):
                    self._app_items.append(i)
                else:
                    self._app_items.append(RecruitContentAppItem.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.app_items:
            if isinstance(self.app_items, list):
                for i in range(0, len(self.app_items)):
                    element = self.app_items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.app_items[i] = element.to_alipay_dict()
            if hasattr(self.app_items, 'to_alipay_dict'):
                params['app_items'] = self.app_items.to_alipay_dict()
            else:
                params['app_items'] = self.app_items
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RecruitEnrollContent()
        if 'app_items' in d:
            o.app_items = d['app_items']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MedicalOnlineCreateAndPayInfo(object):

    def __init__(self):
        self._chnl_ord_sn = None
        self._med_org_ord = None
        self._out_trade_no = None
        self._pay_order_id = None
        self._pay_url = None
        self._status = None

    @property
    def chnl_ord_sn(self):
        return self._chnl_ord_sn

    @chnl_ord_sn.setter
    def chnl_ord_sn(self, value):
        self._chnl_ord_sn = value
    @property
    def med_org_ord(self):
        return self._med_org_ord

    @med_org_ord.setter
    def med_org_ord(self, value):
        self._med_org_ord = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def pay_order_id(self):
        return self._pay_order_id

    @pay_order_id.setter
    def pay_order_id(self, value):
        self._pay_order_id = value
    @property
    def pay_url(self):
        return self._pay_url

    @pay_url.setter
    def pay_url(self, value):
        self._pay_url = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.chnl_ord_sn:
            if hasattr(self.chnl_ord_sn, 'to_alipay_dict'):
                params['chnl_ord_sn'] = self.chnl_ord_sn.to_alipay_dict()
            else:
                params['chnl_ord_sn'] = self.chnl_ord_sn
        if self.med_org_ord:
            if hasattr(self.med_org_ord, 'to_alipay_dict'):
                params['med_org_ord'] = self.med_org_ord.to_alipay_dict()
            else:
                params['med_org_ord'] = self.med_org_ord
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.pay_order_id:
            if hasattr(self.pay_order_id, 'to_alipay_dict'):
                params['pay_order_id'] = self.pay_order_id.to_alipay_dict()
            else:
                params['pay_order_id'] = self.pay_order_id
        if self.pay_url:
            if hasattr(self.pay_url, 'to_alipay_dict'):
                params['pay_url'] = self.pay_url.to_alipay_dict()
            else:
                params['pay_url'] = self.pay_url
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MedicalOnlineCreateAndPayInfo()
        if 'chnl_ord_sn' in d:
            o.chnl_ord_sn = d['chnl_ord_sn']
        if 'med_org_ord' in d:
            o.med_org_ord = d['med_org_ord']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'pay_order_id' in d:
            o.pay_order_id = d['pay_order_id']
        if 'pay_url' in d:
            o.pay_url = d['pay_url']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayIserviceCcmRobotAvatarbaseQueryModel(object):

    def __init__(self):
        self._method_params = None
        self._target_method = None
        self._tenant_code = None

    @property
    def method_params(self):
        return self._method_params

    @method_params.setter
    def method_params(self, value):
        self._method_params = value
    @property
    def target_method(self):
        return self._target_method

    @target_method.setter
    def target_method(self, value):
        self._target_method = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.method_params:
            if hasattr(self.method_params, 'to_alipay_dict'):
                params['method_params'] = self.method_params.to_alipay_dict()
            else:
                params['method_params'] = self.method_params
        if self.target_method:
            if hasattr(self.target_method, 'to_alipay_dict'):
                params['target_method'] = self.target_method.to_alipay_dict()
            else:
                params['target_method'] = self.target_method
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCcmRobotAvatarbaseQueryModel()
        if 'method_params' in d:
            o.method_params = d['method_params']
        if 'target_method' in d:
            o.target_method = d['target_method']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PlantPlace(object):

    def __init__(self):
        self._acreage = None
        self._forest_id = None
        self._forest_name = None
        self._location = None
        self._ngo_name = None
        self._plant_time = None
        self._region = None
        self._tree_count = None

    @property
    def acreage(self):
        return self._acreage

    @acreage.setter
    def acreage(self, value):
        self._acreage = value
    @property
    def forest_id(self):
        return self._forest_id

    @forest_id.setter
    def forest_id(self, value):
        self._forest_id = value
    @property
    def forest_name(self):
        return self._forest_name

    @forest_name.setter
    def forest_name(self, value):
        self._forest_name = value
    @property
    def location(self):
        return self._location

    @location.setter
    def location(self, value):
        self._location = value
    @property
    def ngo_name(self):
        return self._ngo_name

    @ngo_name.setter
    def ngo_name(self, value):
        self._ngo_name = value
    @property
    def plant_time(self):
        return self._plant_time

    @plant_time.setter
    def plant_time(self, value):
        self._plant_time = value
    @property
    def region(self):
        return self._region

    @region.setter
    def region(self, value):
        self._region = value
    @property
    def tree_count(self):
        return self._tree_count

    @tree_count.setter
    def tree_count(self, value):
        self._tree_count = value


    def to_alipay_dict(self):
        params = dict()
        if self.acreage:
            if hasattr(self.acreage, 'to_alipay_dict'):
                params['acreage'] = self.acreage.to_alipay_dict()
            else:
                params['acreage'] = self.acreage
        if self.forest_id:
            if hasattr(self.forest_id, 'to_alipay_dict'):
                params['forest_id'] = self.forest_id.to_alipay_dict()
            else:
                params['forest_id'] = self.forest_id
        if self.forest_name:
            if hasattr(self.forest_name, 'to_alipay_dict'):
                params['forest_name'] = self.forest_name.to_alipay_dict()
            else:
                params['forest_name'] = self.forest_name
        if self.location:
            if hasattr(self.location, 'to_alipay_dict'):
                params['location'] = self.location.to_alipay_dict()
            else:
                params['location'] = self.location
        if self.ngo_name:
            if hasattr(self.ngo_name, 'to_alipay_dict'):
                params['ngo_name'] = self.ngo_name.to_alipay_dict()
            else:
                params['ngo_name'] = self.ngo_name
        if self.plant_time:
            if hasattr(self.plant_time, 'to_alipay_dict'):
                params['plant_time'] = self.plant_time.to_alipay_dict()
            else:
                params['plant_time'] = self.plant_time
        if self.region:
            if hasattr(self.region, 'to_alipay_dict'):
                params['region'] = self.region.to_alipay_dict()
            else:
                params['region'] = self.region
        if self.tree_count:
            if hasattr(self.tree_count, 'to_alipay_dict'):
                params['tree_count'] = self.tree_count.to_alipay_dict()
            else:
                params['tree_count'] = self.tree_count
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PlantPlace()
        if 'acreage' in d:
            o.acreage = d['acreage']
        if 'forest_id' in d:
            o.forest_id = d['forest_id']
        if 'forest_name' in d:
            o.forest_name = d['forest_name']
        if 'location' in d:
            o.location = d['location']
        if 'ngo_name' in d:
            o.ngo_name = d['ngo_name']
        if 'plant_time' in d:
            o.plant_time = d['plant_time']
        if 'region' in d:
            o.region = d['region']
        if 'tree_count' in d:
            o.tree_count = d['tree_count']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ContactInfoKt(object):

    def __init__(self):
        self._email = None
        self._id_card_no = None
        self._mobile = None
        self._name = None
        self._phone = None
        self._tag = None
        self._type = None

    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def id_card_no(self):
        return self._id_card_no

    @id_card_no.setter
    def id_card_no(self, value):
        self._id_card_no = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value
    @property
    def tag(self):
        return self._tag

    @tag.setter
    def tag(self, value):
        if isinstance(value, list):
            self._tag = list()
            for i in value:
                self._tag.append(i)
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.id_card_no:
            if hasattr(self.id_card_no, 'to_alipay_dict'):
                params['id_card_no'] = self.id_card_no.to_alipay_dict()
            else:
                params['id_card_no'] = self.id_card_no
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.tag:
            if isinstance(self.tag, list):
                for i in range(0, len(self.tag)):
                    element = self.tag[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tag[i] = element.to_alipay_dict()
            if hasattr(self.tag, 'to_alipay_dict'):
                params['tag'] = self.tag.to_alipay_dict()
            else:
                params['tag'] = self.tag
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ContactInfoKt()
        if 'email' in d:
            o.email = d['email']
        if 'id_card_no' in d:
            o.id_card_no = d['id_card_no']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'name' in d:
            o.name = d['name']
        if 'phone' in d:
            o.phone = d['phone']
        if 'tag' in d:
            o.tag = d['tag']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenSearchAppkeywordquotaQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenSearchAppkeywordquotaQueryResponse, self).__init__()
        self._quota_num = None

    @property
    def quota_num(self):
        return self._quota_num

    @quota_num.setter
    def quota_num(self, value):
        self._quota_num = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenSearchAppkeywordquotaQueryResponse, self).parse_response_content(response_content)
        if 'quota_num' in response:
            self.quota_num = response['quota_num']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchPartAgreeInfo(object):

    def __init__(self):
        self._audit_info = None
        self._audit_operator = None
        self._audit_reason = None
        self._audit_type = None

    @property
    def audit_info(self):
        return self._audit_info

    @audit_info.setter
    def audit_info(self, value):
        self._audit_info = value
    @property
    def audit_operator(self):
        return self._audit_operator

    @audit_operator.setter
    def audit_operator(self, value):
        self._audit_operator = value
    @property
    def audit_reason(self):
        return self._audit_reason

    @audit_reason.setter
    def audit_reason(self, value):
        self._audit_reason = value
    @property
    def audit_type(self):
        return self._audit_type

    @audit_type.setter
    def audit_type(self, value):
        self._audit_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.audit_info:
            if hasattr(self.audit_info, 'to_alipay_dict'):
                params['audit_info'] = self.audit_info.to_alipay_dict()
            else:
                params['audit_info'] = self.audit_info
        if self.audit_operator:
            if hasattr(self.audit_operator, 'to_alipay_dict'):
                params['audit_operator'] = self.audit_operator.to_alipay_dict()
            else:
                params['audit_operator'] = self.audit_operator
        if self.audit_reason:
            if hasattr(self.audit_reason, 'to_alipay_dict'):
                params['audit_reason'] = self.audit_reason.to_alipay_dict()
            else:
                params['audit_reason'] = self.audit_reason
        if self.audit_type:
            if hasattr(self.audit_type, 'to_alipay_dict'):
                params['audit_type'] = self.audit_type.to_alipay_dict()
            else:
                params['audit_type'] = self.audit_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchPartAgreeInfo()
        if 'audit_info' in d:
            o.audit_info = d['audit_info']
        if 'audit_operator' in d:
            o.audit_operator = d['audit_operator']
        if 'audit_reason' in d:
            o.audit_reason = d['audit_reason']
        if 'audit_type' in d:
            o.audit_type = d['audit_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppMessageSubscriptionQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppMessageSubscriptionQueryResponse, self).__init__()
        self._comm_type = None
        self._tag = None
        self._topic = None

    @property
    def comm_type(self):
        return self._comm_type

    @comm_type.setter
    def comm_type(self, value):
        self._comm_type = value
    @property
    def tag(self):
        return self._tag

    @tag.setter
    def tag(self, value):
        self._tag = value
    @property
    def topic(self):
        return self._topic

    @topic.setter
    def topic(self, value):
        self._topic = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppMessageSubscriptionQueryResponse, self).parse_response_content(response_content)
        if 'comm_type' in response:
            self.comm_type = response['comm_type']
        if 'tag' in response:
            self.tag = response['tag']
        if 'topic' in response:
            self.topic = response['topic']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AliveSubtitleExt import AliveSubtitleExt


class AntfortuneContentCommunitySubtitleQueryModel(object):

    def __init__(self):
        self._content = None
        self._ext = None
        self._live_id = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def ext(self):
        return self._ext

    @ext.setter
    def ext(self, value):
        if isinstance(value, AliveSubtitleExt):
            self._ext = value
        else:
            self._ext = AliveSubtitleExt.from_alipay_dict(value)
    @property
    def live_id(self):
        return self._live_id

    @live_id.setter
    def live_id(self, value):
        self._live_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.ext:
            if hasattr(self.ext, 'to_alipay_dict'):
                params['ext'] = self.ext.to_alipay_dict()
            else:
                params['ext'] = self.ext
        if self.live_id:
            if hasattr(self.live_id, 'to_alipay_dict'):
                params['live_id'] = self.live_id.to_alipay_dict()
            else:
                params['live_id'] = self.live_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntfortuneContentCommunitySubtitleQueryModel()
        if 'content' in d:
            o.content = d['content']
        if 'ext' in d:
            o.ext = d['ext']
        if 'live_id' in d:
            o.live_id = d['live_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenFundComponentDetailDTO(object):

    def __init__(self):
        self._amount = None
        self._cash = None
        self._component_id = None
        self._component_type = None
        self._fund_account = None
        self._fund_sub_account = None
        self._fund_type = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def cash(self):
        return self._cash

    @cash.setter
    def cash(self, value):
        self._cash = value
    @property
    def component_id(self):
        return self._component_id

    @component_id.setter
    def component_id(self, value):
        self._component_id = value
    @property
    def component_type(self):
        return self._component_type

    @component_type.setter
    def component_type(self, value):
        self._component_type = value
    @property
    def fund_account(self):
        return self._fund_account

    @fund_account.setter
    def fund_account(self, value):
        self._fund_account = value
    @property
    def fund_sub_account(self):
        return self._fund_sub_account

    @fund_sub_account.setter
    def fund_sub_account(self, value):
        self._fund_sub_account = value
    @property
    def fund_type(self):
        return self._fund_type

    @fund_type.setter
    def fund_type(self, value):
        self._fund_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.cash:
            if hasattr(self.cash, 'to_alipay_dict'):
                params['cash'] = self.cash.to_alipay_dict()
            else:
                params['cash'] = self.cash
        if self.component_id:
            if hasattr(self.component_id, 'to_alipay_dict'):
                params['component_id'] = self.component_id.to_alipay_dict()
            else:
                params['component_id'] = self.component_id
        if self.component_type:
            if hasattr(self.component_type, 'to_alipay_dict'):
                params['component_type'] = self.component_type.to_alipay_dict()
            else:
                params['component_type'] = self.component_type
        if self.fund_account:
            if hasattr(self.fund_account, 'to_alipay_dict'):
                params['fund_account'] = self.fund_account.to_alipay_dict()
            else:
                params['fund_account'] = self.fund_account
        if self.fund_sub_account:
            if hasattr(self.fund_sub_account, 'to_alipay_dict'):
                params['fund_sub_account'] = self.fund_sub_account.to_alipay_dict()
            else:
                params['fund_sub_account'] = self.fund_sub_account
        if self.fund_type:
            if hasattr(self.fund_type, 'to_alipay_dict'):
                params['fund_type'] = self.fund_type.to_alipay_dict()
            else:
                params['fund_type'] = self.fund_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenFundComponentDetailDTO()
        if 'amount' in d:
            o.amount = d['amount']
        if 'cash' in d:
            o.cash = d['cash']
        if 'component_id' in d:
            o.component_id = d['component_id']
        if 'component_type' in d:
            o.component_type = d['component_type']
        if 'fund_account' in d:
            o.fund_account = d['fund_account']
        if 'fund_sub_account' in d:
            o.fund_sub_account = d['fund_sub_account']
        if 'fund_type' in d:
            o.fund_type = d['fund_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundZcardprodUserQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundZcardprodUserQueryResponse, self).__init__()
        self._asset_id = None
        self._bind_status = None

    @property
    def asset_id(self):
        return self._asset_id

    @asset_id.setter
    def asset_id(self, value):
        self._asset_id = value
    @property
    def bind_status(self):
        return self._bind_status

    @bind_status.setter
    def bind_status(self, value):
        self._bind_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundZcardprodUserQueryResponse, self).parse_response_content(response_content)
        if 'asset_id' in response:
            self.asset_id = response['asset_id']
        if 'bind_status' in response:
            self.bind_status = response['bind_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportTaxiDriverauthenQueryModel(object):

    def __init__(self):
        self._driver_open_id = None
        self._driver_user_id = None
        self._request_time = None

    @property
    def driver_open_id(self):
        return self._driver_open_id

    @driver_open_id.setter
    def driver_open_id(self, value):
        self._driver_open_id = value
    @property
    def driver_user_id(self):
        return self._driver_user_id

    @driver_user_id.setter
    def driver_user_id(self, value):
        self._driver_user_id = value
    @property
    def request_time(self):
        return self._request_time

    @request_time.setter
    def request_time(self, value):
        self._request_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.driver_open_id:
            if hasattr(self.driver_open_id, 'to_alipay_dict'):
                params['driver_open_id'] = self.driver_open_id.to_alipay_dict()
            else:
                params['driver_open_id'] = self.driver_open_id
        if self.driver_user_id:
            if hasattr(self.driver_user_id, 'to_alipay_dict'):
                params['driver_user_id'] = self.driver_user_id.to_alipay_dict()
            else:
                params['driver_user_id'] = self.driver_user_id
        if self.request_time:
            if hasattr(self.request_time, 'to_alipay_dict'):
                params['request_time'] = self.request_time.to_alipay_dict()
            else:
                params['request_time'] = self.request_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportTaxiDriverauthenQueryModel()
        if 'driver_open_id' in d:
            o.driver_open_id = d['driver_open_id']
        if 'driver_user_id' in d:
            o.driver_user_id = d['driver_user_id']
        if 'request_time' in d:
            o.request_time = d['request_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RankingDetailInfo(object):

    def __init__(self):
        self._point = None

    @property
    def point(self):
        return self._point

    @point.setter
    def point(self, value):
        self._point = value


    def to_alipay_dict(self):
        params = dict()
        if self.point:
            if hasattr(self.point, 'to_alipay_dict'):
                params['point'] = self.point.to_alipay_dict()
            else:
                params['point'] = self.point
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RankingDetailInfo()
        if 'point' in d:
            o.point = d['point']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncPriceTaskCreateModel(object):

    def __init__(self):
        self._app_name = None
        self._apply_detail = None
        self._context = None
        self._create_user = None
        self._gmt_create = None
        self._memo = None
        self._out_biz_no = None
        self._source = None
        self._sub_type = None
        self._tnt_inst_id = None
        self._type = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def apply_detail(self):
        return self._apply_detail

    @apply_detail.setter
    def apply_detail(self, value):
        self._apply_detail = value
    @property
    def context(self):
        return self._context

    @context.setter
    def context(self, value):
        self._context = value
    @property
    def create_user(self):
        return self._create_user

    @create_user.setter
    def create_user(self, value):
        self._create_user = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def sub_type(self):
        return self._sub_type

    @sub_type.setter
    def sub_type(self, value):
        self._sub_type = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.apply_detail:
            if hasattr(self.apply_detail, 'to_alipay_dict'):
                params['apply_detail'] = self.apply_detail.to_alipay_dict()
            else:
                params['apply_detail'] = self.apply_detail
        if self.context:
            if hasattr(self.context, 'to_alipay_dict'):
                params['context'] = self.context.to_alipay_dict()
            else:
                params['context'] = self.context
        if self.create_user:
            if hasattr(self.create_user, 'to_alipay_dict'):
                params['create_user'] = self.create_user.to_alipay_dict()
            else:
                params['create_user'] = self.create_user
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.sub_type:
            if hasattr(self.sub_type, 'to_alipay_dict'):
                params['sub_type'] = self.sub_type.to_alipay_dict()
            else:
                params['sub_type'] = self.sub_type
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncPriceTaskCreateModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'apply_detail' in d:
            o.apply_detail = d['apply_detail']
        if 'context' in d:
            o.context = d['context']
        if 'create_user' in d:
            o.create_user = d['create_user']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'memo' in d:
            o.memo = d['memo']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'source' in d:
            o.source = d['source']
        if 'sub_type' in d:
            o.sub_type = d['sub_type']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundEnterprisepayMemberjointurlApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundEnterprisepayMemberjointurlApplyResponse, self).__init__()
        self._apply_url = None
        self._apply_url_token = None
        self._expiration_time = None

    @property
    def apply_url(self):
        return self._apply_url

    @apply_url.setter
    def apply_url(self, value):
        self._apply_url = value
    @property
    def apply_url_token(self):
        return self._apply_url_token

    @apply_url_token.setter
    def apply_url_token(self, value):
        self._apply_url_token = value
    @property
    def expiration_time(self):
        return self._expiration_time

    @expiration_time.setter
    def expiration_time(self, value):
        self._expiration_time = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundEnterprisepayMemberjointurlApplyResponse, self).parse_response_content(response_content)
        if 'apply_url' in response:
            self.apply_url = response['apply_url']
        if 'apply_url_token' in response:
            self.apply_url_token = response['apply_url_token']
        if 'expiration_time' in response:
            self.expiration_time = response['expiration_time']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MyxiaojinFinanceBudgetConsumedamountBatchqueryModel(object):

    def __init__(self):
        self._biz_uk_ids = None
        self._ns = None

    @property
    def biz_uk_ids(self):
        return self._biz_uk_ids

    @biz_uk_ids.setter
    def biz_uk_ids(self, value):
        if isinstance(value, list):
            self._biz_uk_ids = list()
            for i in value:
                self._biz_uk_ids.append(i)
    @property
    def ns(self):
        return self._ns

    @ns.setter
    def ns(self, value):
        self._ns = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_uk_ids:
            if isinstance(self.biz_uk_ids, list):
                for i in range(0, len(self.biz_uk_ids)):
                    element = self.biz_uk_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.biz_uk_ids[i] = element.to_alipay_dict()
            if hasattr(self.biz_uk_ids, 'to_alipay_dict'):
                params['biz_uk_ids'] = self.biz_uk_ids.to_alipay_dict()
            else:
                params['biz_uk_ids'] = self.biz_uk_ids
        if self.ns:
            if hasattr(self.ns, 'to_alipay_dict'):
                params['ns'] = self.ns.to_alipay_dict()
            else:
                params['ns'] = self.ns
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MyxiaojinFinanceBudgetConsumedamountBatchqueryModel()
        if 'biz_uk_ids' in d:
            o.biz_uk_ids = d['biz_uk_ids']
        if 'ns' in d:
            o.ns = d['ns']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantMrchsurplmitemIncrementSyncModel(object):

    def __init__(self):
        self._biz_id = None
        self._item_list = None
        self._request_id = None
        self._sub_biz_id = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def item_list(self):
        return self._item_list

    @item_list.setter
    def item_list(self, value):
        self._item_list = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def sub_biz_id(self):
        return self._sub_biz_id

    @sub_biz_id.setter
    def sub_biz_id(self, value):
        self._sub_biz_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.item_list:
            if hasattr(self.item_list, 'to_alipay_dict'):
                params['item_list'] = self.item_list.to_alipay_dict()
            else:
                params['item_list'] = self.item_list
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.sub_biz_id:
            if hasattr(self.sub_biz_id, 'to_alipay_dict'):
                params['sub_biz_id'] = self.sub_biz_id.to_alipay_dict()
            else:
                params['sub_biz_id'] = self.sub_biz_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantMrchsurplmitemIncrementSyncModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'item_list' in d:
            o.item_list = d['item_list']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'sub_biz_id' in d:
            o.sub_biz_id = d['sub_biz_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingVoucherStockQueryModel(object):

    def __init__(self):
        self._stock_id = None

    @property
    def stock_id(self):
        return self._stock_id

    @stock_id.setter
    def stock_id(self, value):
        self._stock_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.stock_id:
            if hasattr(self.stock_id, 'to_alipay_dict'):
                params['stock_id'] = self.stock_id.to_alipay_dict()
            else:
                params['stock_id'] = self.stock_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingVoucherStockQueryModel()
        if 'stock_id' in d:
            o.stock_id = d['stock_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdIrisVerifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdIrisVerifyResponse, self).__init__()
        self._biz_token = None
        self._ext_info = None
        self._iris_id = None
        self._person_id = None
        self._status = None

    @property
    def biz_token(self):
        return self._biz_token

    @biz_token.setter
    def biz_token(self, value):
        self._biz_token = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def iris_id(self):
        return self._iris_id

    @iris_id.setter
    def iris_id(self, value):
        self._iris_id = value
    @property
    def person_id(self):
        return self._person_id

    @person_id.setter
    def person_id(self, value):
        self._person_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdIrisVerifyResponse, self).parse_response_content(response_content)
        if 'biz_token' in response:
            self.biz_token = response['biz_token']
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'iris_id' in response:
            self.iris_id = response['iris_id']
        if 'person_id' in response:
            self.person_id = response['person_id']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AccessParams import AccessParams
from alipay.aop.api.domain.DeviceParams import DeviceParams
from alipay.aop.api.domain.IdentityParams import IdentityParams
from alipay.aop.api.domain.PeriodRuleParams import PeriodRuleParams
from alipay.aop.api.domain.ProdParams import ProdParams
from alipay.aop.api.domain.SpecifiedAsset import SpecifiedAsset
from alipay.aop.api.domain.SpecifiedChannelParam import SpecifiedChannelParam
from alipay.aop.api.domain.SubMerchantParams import SubMerchantParams
from alipay.aop.api.domain.ZmAuthParams import ZmAuthParams


class AlipayUserAgreementPageSignModel(object):

    def __init__(self):
        self._access_params = None
        self._agreement_effect_type = None
        self._allow_huazhi_degrade = None
        self._device_params = None
        self._effect_time = None
        self._external_agreement_no = None
        self._external_logon_id = None
        self._identity_params = None
        self._merchant_process_url = None
        self._pass_params = None
        self._period_rule_params = None
        self._personal_product_code = None
        self._prod_params = None
        self._product_code = None
        self._promo_params = None
        self._sign_scene = None
        self._sign_validity_period = None
        self._specified_asset = None
        self._specified_sort_channel_params = None
        self._sub_merchant = None
        self._third_party_type = None
        self._user_age_range = None
        self._zm_auth_params = None

    @property
    def access_params(self):
        return self._access_params

    @access_params.setter
    def access_params(self, value):
        if isinstance(value, AccessParams):
            self._access_params = value
        else:
            self._access_params = AccessParams.from_alipay_dict(value)
    @property
    def agreement_effect_type(self):
        return self._agreement_effect_type

    @agreement_effect_type.setter
    def agreement_effect_type(self, value):
        self._agreement_effect_type = value
    @property
    def allow_huazhi_degrade(self):
        return self._allow_huazhi_degrade

    @allow_huazhi_degrade.setter
    def allow_huazhi_degrade(self, value):
        self._allow_huazhi_degrade = value
    @property
    def device_params(self):
        return self._device_params

    @device_params.setter
    def device_params(self, value):
        if isinstance(value, DeviceParams):
            self._device_params = value
        else:
            self._device_params = DeviceParams.from_alipay_dict(value)
    @property
    def effect_time(self):
        return self._effect_time

    @effect_time.setter
    def effect_time(self, value):
        self._effect_time = value
    @property
    def external_agreement_no(self):
        return self._external_agreement_no

    @external_agreement_no.setter
    def external_agreement_no(self, value):
        self._external_agreement_no = value
    @property
    def external_logon_id(self):
        return self._external_logon_id

    @external_logon_id.setter
    def external_logon_id(self, value):
        self._external_logon_id = value
    @property
    def identity_params(self):
        return self._identity_params

    @identity_params.setter
    def identity_params(self, value):
        if isinstance(value, IdentityParams):
            self._identity_params = value
        else:
            self._identity_params = IdentityParams.from_alipay_dict(value)
    @property
    def merchant_process_url(self):
        return self._merchant_process_url

    @merchant_process_url.setter
    def merchant_process_url(self, value):
        self._merchant_process_url = value
    @property
    def pass_params(self):
        return self._pass_params

    @pass_params.setter
    def pass_params(self, value):
        self._pass_params = value
    @property
    def period_rule_params(self):
        return self._period_rule_params

    @period_rule_params.setter
    def period_rule_params(self, value):
        if isinstance(value, PeriodRuleParams):
            self._period_rule_params = value
        else:
            self._period_rule_params = PeriodRuleParams.from_alipay_dict(value)
    @property
    def personal_product_code(self):
        return self._personal_product_code

    @personal_product_code.setter
    def personal_product_code(self, value):
        self._personal_product_code = value
    @property
    def prod_params(self):
        return self._prod_params

    @prod_params.setter
    def prod_params(self, value):
        if isinstance(value, ProdParams):
            self._prod_params = value
        else:
            self._prod_params = ProdParams.from_alipay_dict(value)
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def promo_params(self):
        return self._promo_params

    @promo_params.setter
    def promo_params(self, value):
        self._promo_params = value
    @property
    def sign_scene(self):
        return self._sign_scene

    @sign_scene.setter
    def sign_scene(self, value):
        self._sign_scene = value
    @property
    def sign_validity_period(self):
        return self._sign_validity_period

    @sign_validity_period.setter
    def sign_validity_period(self, value):
        self._sign_validity_period = value
    @property
    def specified_asset(self):
        return self._specified_asset

    @specified_asset.setter
    def specified_asset(self, value):
        if isinstance(value, SpecifiedAsset):
            self._specified_asset = value
        else:
            self._specified_asset = SpecifiedAsset.from_alipay_dict(value)
    @property
    def specified_sort_channel_params(self):
        return self._specified_sort_channel_params

    @specified_sort_channel_params.setter
    def specified_sort_channel_params(self, value):
        if isinstance(value, SpecifiedChannelParam):
            self._specified_sort_channel_params = value
        else:
            self._specified_sort_channel_params = SpecifiedChannelParam.from_alipay_dict(value)
    @property
    def sub_merchant(self):
        return self._sub_merchant

    @sub_merchant.setter
    def sub_merchant(self, value):
        if isinstance(value, SubMerchantParams):
            self._sub_merchant = value
        else:
            self._sub_merchant = SubMerchantParams.from_alipay_dict(value)
    @property
    def third_party_type(self):
        return self._third_party_type

    @third_party_type.setter
    def third_party_type(self, value):
        self._third_party_type = value
    @property
    def user_age_range(self):
        return self._user_age_range

    @user_age_range.setter
    def user_age_range(self, value):
        self._user_age_range = value
    @property
    def zm_auth_params(self):
        return self._zm_auth_params

    @zm_auth_params.setter
    def zm_auth_params(self, value):
        if isinstance(value, ZmAuthParams):
            self._zm_auth_params = value
        else:
            self._zm_auth_params = ZmAuthParams.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.access_params:
            if hasattr(self.access_params, 'to_alipay_dict'):
                params['access_params'] = self.access_params.to_alipay_dict()
            else:
                params['access_params'] = self.access_params
        if self.agreement_effect_type:
            if hasattr(self.agreement_effect_type, 'to_alipay_dict'):
                params['agreement_effect_type'] = self.agreement_effect_type.to_alipay_dict()
            else:
                params['agreement_effect_type'] = self.agreement_effect_type
        if self.allow_huazhi_degrade:
            if hasattr(self.allow_huazhi_degrade, 'to_alipay_dict'):
                params['allow_huazhi_degrade'] = self.allow_huazhi_degrade.to_alipay_dict()
            else:
                params['allow_huazhi_degrade'] = self.allow_huazhi_degrade
        if self.device_params:
            if hasattr(self.device_params, 'to_alipay_dict'):
                params['device_params'] = self.device_params.to_alipay_dict()
            else:
                params['device_params'] = self.device_params
        if self.effect_time:
            if hasattr(self.effect_time, 'to_alipay_dict'):
                params['effect_time'] = self.effect_time.to_alipay_dict()
            else:
                params['effect_time'] = self.effect_time
        if self.external_agreement_no:
            if hasattr(self.external_agreement_no, 'to_alipay_dict'):
                params['external_agreement_no'] = self.external_agreement_no.to_alipay_dict()
            else:
                params['external_agreement_no'] = self.external_agreement_no
        if self.external_logon_id:
            if hasattr(self.external_logon_id, 'to_alipay_dict'):
                params['external_logon_id'] = self.external_logon_id.to_alipay_dict()
            else:
                params['external_logon_id'] = self.external_logon_id
        if self.identity_params:
            if hasattr(self.identity_params, 'to_alipay_dict'):
                params['identity_params'] = self.identity_params.to_alipay_dict()
            else:
                params['identity_params'] = self.identity_params
        if self.merchant_process_url:
            if hasattr(self.merchant_process_url, 'to_alipay_dict'):
                params['merchant_process_url'] = self.merchant_process_url.to_alipay_dict()
            else:
                params['merchant_process_url'] = self.merchant_process_url
        if self.pass_params:
            if hasattr(self.pass_params, 'to_alipay_dict'):
                params['pass_params'] = self.pass_params.to_alipay_dict()
            else:
                params['pass_params'] = self.pass_params
        if self.period_rule_params:
            if hasattr(self.period_rule_params, 'to_alipay_dict'):
                params['period_rule_params'] = self.period_rule_params.to_alipay_dict()
            else:
                params['period_rule_params'] = self.period_rule_params
        if self.personal_product_code:
            if hasattr(self.personal_product_code, 'to_alipay_dict'):
                params['personal_product_code'] = self.personal_product_code.to_alipay_dict()
            else:
                params['personal_product_code'] = self.personal_product_code
        if self.prod_params:
            if hasattr(self.prod_params, 'to_alipay_dict'):
                params['prod_params'] = self.prod_params.to_alipay_dict()
            else:
                params['prod_params'] = self.prod_params
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.promo_params:
            if hasattr(self.promo_params, 'to_alipay_dict'):
                params['promo_params'] = self.promo_params.to_alipay_dict()
            else:
                params['promo_params'] = self.promo_params
        if self.sign_scene:
            if hasattr(self.sign_scene, 'to_alipay_dict'):
                params['sign_scene'] = self.sign_scene.to_alipay_dict()
            else:
                params['sign_scene'] = self.sign_scene
        if self.sign_validity_period:
            if hasattr(self.sign_validity_period, 'to_alipay_dict'):
                params['sign_validity_period'] = self.sign_validity_period.to_alipay_dict()
            else:
                params['sign_validity_period'] = self.sign_validity_period
        if self.specified_asset:
            if hasattr(self.specified_asset, 'to_alipay_dict'):
                params['specified_asset'] = self.specified_asset.to_alipay_dict()
            else:
                params['specified_asset'] = self.specified_asset
        if self.specified_sort_channel_params:
            if hasattr(self.specified_sort_channel_params, 'to_alipay_dict'):
                params['specified_sort_channel_params'] = self.specified_sort_channel_params.to_alipay_dict()
            else:
                params['specified_sort_channel_params'] = self.specified_sort_channel_params
        if self.sub_merchant:
            if hasattr(self.sub_merchant, 'to_alipay_dict'):
                params['sub_merchant'] = self.sub_merchant.to_alipay_dict()
            else:
                params['sub_merchant'] = self.sub_merchant
        if self.third_party_type:
            if hasattr(self.third_party_type, 'to_alipay_dict'):
                params['third_party_type'] = self.third_party_type.to_alipay_dict()
            else:
                params['third_party_type'] = self.third_party_type
        if self.user_age_range:
            if hasattr(self.user_age_range, 'to_alipay_dict'):
                params['user_age_range'] = self.user_age_range.to_alipay_dict()
            else:
                params['user_age_range'] = self.user_age_range
        if self.zm_auth_params:
            if hasattr(self.zm_auth_params, 'to_alipay_dict'):
                params['zm_auth_params'] = self.zm_auth_params.to_alipay_dict()
            else:
                params['zm_auth_params'] = self.zm_auth_params
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAgreementPageSignModel()
        if 'access_params' in d:
            o.access_params = d['access_params']
        if 'agreement_effect_type' in d:
            o.agreement_effect_type = d['agreement_effect_type']
        if 'allow_huazhi_degrade' in d:
            o.allow_huazhi_degrade = d['allow_huazhi_degrade']
        if 'device_params' in d:
            o.device_params = d['device_params']
        if 'effect_time' in d:
            o.effect_time = d['effect_time']
        if 'external_agreement_no' in d:
            o.external_agreement_no = d['external_agreement_no']
        if 'external_logon_id' in d:
            o.external_logon_id = d['external_logon_id']
        if 'identity_params' in d:
            o.identity_params = d['identity_params']
        if 'merchant_process_url' in d:
            o.merchant_process_url = d['merchant_process_url']
        if 'pass_params' in d:
            o.pass_params = d['pass_params']
        if 'period_rule_params' in d:
            o.period_rule_params = d['period_rule_params']
        if 'personal_product_code' in d:
            o.personal_product_code = d['personal_product_code']
        if 'prod_params' in d:
            o.prod_params = d['prod_params']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'promo_params' in d:
            o.promo_params = d['promo_params']
        if 'sign_scene' in d:
            o.sign_scene = d['sign_scene']
        if 'sign_validity_period' in d:
            o.sign_validity_period = d['sign_validity_period']
        if 'specified_asset' in d:
            o.specified_asset = d['specified_asset']
        if 'specified_sort_channel_params' in d:
            o.specified_sort_channel_params = d['specified_sort_channel_params']
        if 'sub_merchant' in d:
            o.sub_merchant = d['sub_merchant']
        if 'third_party_type' in d:
            o.third_party_type = d['third_party_type']
        if 'user_age_range' in d:
            o.user_age_range = d['user_age_range']
        if 'zm_auth_params' in d:
            o.zm_auth_params = d['zm_auth_params']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AssetInfoCorrectionItem import AssetInfoCorrectionItem


class AntMerchantExpandAssetinfoCorrectionSyncModel(object):

    def __init__(self):
        self._asset_correction = None

    @property
    def asset_correction(self):
        return self._asset_correction

    @asset_correction.setter
    def asset_correction(self, value):
        if isinstance(value, AssetInfoCorrectionItem):
            self._asset_correction = value
        else:
            self._asset_correction = AssetInfoCorrectionItem.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.asset_correction:
            if hasattr(self.asset_correction, 'to_alipay_dict'):
                params['asset_correction'] = self.asset_correction.to_alipay_dict()
            else:
                params['asset_correction'] = self.asset_correction
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandAssetinfoCorrectionSyncModel()
        if 'asset_correction' in d:
            o.asset_correction = d['asset_correction']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenSpIsvBillSyncModel(object):

    def __init__(self):
        self._end_time = None
        self._generate_time = None
        self._item_code = None
        self._out_biz_no = None
        self._pay_time = None
        self._price = None
        self._promotor_pid = None
        self._start_time = None
        self._status = None
        self._sub_promotor_pid = None

    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def generate_time(self):
        return self._generate_time

    @generate_time.setter
    def generate_time(self, value):
        self._generate_time = value
    @property
    def item_code(self):
        return self._item_code

    @item_code.setter
    def item_code(self, value):
        self._item_code = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def promotor_pid(self):
        return self._promotor_pid

    @promotor_pid.setter
    def promotor_pid(self, value):
        self._promotor_pid = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sub_promotor_pid(self):
        return self._sub_promotor_pid

    @sub_promotor_pid.setter
    def sub_promotor_pid(self, value):
        self._sub_promotor_pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.generate_time:
            if hasattr(self.generate_time, 'to_alipay_dict'):
                params['generate_time'] = self.generate_time.to_alipay_dict()
            else:
                params['generate_time'] = self.generate_time
        if self.item_code:
            if hasattr(self.item_code, 'to_alipay_dict'):
                params['item_code'] = self.item_code.to_alipay_dict()
            else:
                params['item_code'] = self.item_code
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.pay_time:
            if hasattr(self.pay_time, 'to_alipay_dict'):
                params['pay_time'] = self.pay_time.to_alipay_dict()
            else:
                params['pay_time'] = self.pay_time
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.promotor_pid:
            if hasattr(self.promotor_pid, 'to_alipay_dict'):
                params['promotor_pid'] = self.promotor_pid.to_alipay_dict()
            else:
                params['promotor_pid'] = self.promotor_pid
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.sub_promotor_pid:
            if hasattr(self.sub_promotor_pid, 'to_alipay_dict'):
                params['sub_promotor_pid'] = self.sub_promotor_pid.to_alipay_dict()
            else:
                params['sub_promotor_pid'] = self.sub_promotor_pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenSpIsvBillSyncModel()
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'generate_time' in d:
            o.generate_time = d['generate_time']
        if 'item_code' in d:
            o.item_code = d['item_code']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'pay_time' in d:
            o.pay_time = d['pay_time']
        if 'price' in d:
            o.price = d['price']
        if 'promotor_pid' in d:
            o.promotor_pid = d['promotor_pid']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'status' in d:
            o.status = d['status']
        if 'sub_promotor_pid' in d:
            o.sub_promotor_pid = d['sub_promotor_pid']
        return o


